<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Massive_SocialIcons_Widget extends Widget_Base {
	
	public function get_name() {
		return 'massive_social';
	}

	public function get_title() {
		return __('Social Icons', 'massive-addons');
	}

	public function get_icon() {
		return 'eicon-social-icons';
    }
    
    public function get_categories() {
		return ['massive_addons'];
	}

	protected function _register_controls() {

		$this->addcontent();
		$this->addstyle();

	}

	protected function addcontent() {

        $this->start_controls_section(
			'mae_social_content1',
			[
				'label' => __('General', 'massive-addons'),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'style',
			[
				'label' => __('Style', 'massive-addons'),
				'type' => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => [
					'default'  => __( 'Default', 'massive-addons'),
					'flat' => __( 'Flat', 'massive-addons'),
					'symbol' => __( 'Symbol', 'massive-addons'),
				],
			]
		);

		$this->add_control(
			'shape',
			[
				'label' => __('Shape', 'massive-addons'),
				'type' => Controls_Manager::SELECT,
				'default' => 'rounded',
				'options' => [
					'square'  => __( 'Square', 'massive-addons'),
					'rounded' => __( 'Rounded', 'massive-addons'),
					'circle' => __( 'Circle', 'massive-addons'),
				],
			]
		);

		$this->add_control(
			'full_width',
			[
				'label' => __('Full Width', 'massive-addons'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'massive-addons'),
				'label_off' => __( 'No', 'massive-addons'),
				'return_value' => 'mae-social-icons-fullwidth',
				'default' => '',
				'condition' => [
					'shape!' => 'circle'
				]
			]
		);

		$this->add_control(
			'position',
			[
				'label' => __( 'Position', 'massive-addons'),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'massive-addons'),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'massive-addons'),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'massive-addons'),
						'icon' => 'fa fa-align-right',
					],
				],
				'default' => 'center',
				'toggle' => false
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'mae_social_content2',
			[
				'label' => __('Social Icons', 'massive-addons'),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'icons',
			[
				'label' => __('Icons', 'elementor'),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'social' => 'facebook'
					],
					[
						'social' => 'twitter',
					],
					[
						'social' => 'instagram',
					],
					[
						'social' => 'email',
					]
				],
				'fields' => [
					[
						'name' => 'social',
						'label' => __('Icon', 'massive-addons'),
						'label_block' => true,
						'type' => Controls_Manager::SELECT2,
						'multiple' => false,
						'options' => [
							'500px' => __('500px', 'massive-addons'),
							'behance' => __('Behance', 'massive-addons'),
							'badoo' => __('Badoo', 'massive-addons'),
							'blogger' => __('Blogger', 'massive-addons'),
							'codepen' => __('Codepen', 'massive-addons'),
							'delicious' => __('Delicious', 'massive-addons'),
							'deviantart' => __('DeviantArt', 'massive-addons'),
							'digg' => __('Digg', 'massive-addons'),
							'disqus' => __('Disqus', 'massive-addons'),
							'dribbble' => __('Dribbble', 'massive-addons'),
							'email' => __('Email', 'massive-addons'),
							'envato' => __('Envato', 'massive-addons'),
							'evernote' => __('Evernote', 'massive-addons'),
							'facebook' => __('Facebook', 'massive-addons'),
							'fb-messenger' => __('Facebook Messenger', 'massive-addons'),
							'flickr' => __('Flickr', 'massive-addons'),
							'flipboard' => __('Flipboard', 'massive-addons'),
							'forrst' => __('Forrst', 'massive-addons'),
							'foursquare' => __('Foursquare', 'massive-addons'),
							'github' => __('GitHub', 'massive-addons'),
							'google-plus' => __('Google Plus', 'massive-addons'),
							'instagram' => __('Instagram', 'massive-addons'),
							'lastfm' => __('Last.fm', 'massive-addons'),
							'line' => __('Line', 'massive-addons'),
							'lineat' => __('Line@', 'massive-addons'),
							'linkedin' => __('LinkedIn', 'massive-addons'),
							'livejournal' => __('LiveJournal', 'massive-addons'),
							'medium' => __('Medium', 'massive-addons'),
							'meetup' => __('Meetup', 'massive-addons'),
							'myspace' => __('MySpace', 'massive-addons'),
							'odnoklassniki' => __('Odnoklassniki', 'massive-addons'),
							'periscope' => __('Periscope', 'massive-addons'),
							'pinterest' => __('Pinterest', 'massive-addons'),
							'print' => __('Print', 'massive-addons'),
							'producthunt' => __('Product Hunt', 'massive-addons'),
							'reddit' => __('Reddit', 'massive-addons'),
							'rss' => __('RSS', 'massive-addons'),
							'weibo' => __('Weibo', 'massive-addons'),
							'skype' => __('Skype', 'massive-addons'),
							'slack' => __('Slack', 'massive-addons'),
							'snapchat' => __('Snapchat', 'massive-addons'),
							'soundcloud' => __('Soundcloud', 'massive-addons'),
							'spotify' => __('Spotify', 'massive-addons'),
							'stackoverflow' => __('StackOverflow', 'massive-addons'),
							'steam' => __('Steam', 'massive-addons'),
							'stumbleupon' => __('StumbleUpon', 'massive-addons'),
							'telegram' => __('Telegram', 'massive-addons'),
							'tripadvisor' => __('TripAdvisor', 'massive-addons'),
							'tumblr' => __('Tumblr', 'massive-addons'),
							'twitch' => __('Twitch', 'massive-addons'),
							'twitter' => __('Twitter', 'massive-addons'),
							'viadeo' => __('Viadeo', 'massive-addons'),
							'viber' => __('Viber', 'massive-addons'),
							'vimeo' => __('Vimeo', 'massive-addons'),
							'vine' => __('Vine', 'massive-addons'),
							'vk' => __('VK', 'massive-addons'),
							'wechat' => __('WeChat', 'massive-addons'),
							'whatsapp' => __('WhatsApp', 'massive-addons'),
							'wordpress' => __('WordPress', 'massive-addons'),
							'xing' => __('Xing', 'massive-addons'),
							'yelp' => __('Yelp', 'massive-addons'),
							'youtube' => __('YouTube', 'massive-addons'),
						],
						'default' => 'facebook'
					],
					[
						'name' => 'link',
						'label' => __('Link', 'elementor'),
						'type' => Controls_Manager::URL,
						'label_block' => true,
						'default' => [
							'is_external' => true
						],
						'placeholder' => __('https://your-link.com', 'elementor')
					],
				],
				'title_field' => '{{ maeSocialIcons[social] }}',
			]
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'mae_pro',
			[
				'label' => esc_html__('PRO Features', 'massive-addons'),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'mae_pro_html',
			[
				'label' => __( '', 'massive-addons'),
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'content_classes' => 'mae-pro-prepare',
				'raw' => __( '<br/><div>Meet Our Prime Addons for Elementor</div><br/>Thank you for installing our plugin, you can also try our premium version which includes 20+ Creative Addons<br/><br/><a target="_blank" href="http://tiny.cc/prime-pro">View Demo <sup>✱</sup></a>', 'massive-addons'),
			]
		);

		$this->end_controls_section();
	}

	protected function addstyle() {

		$this->start_controls_section(
			'mae_social_style1',
			[
				'label' => __('Social Icon', 'massive-addons'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'spacing',
			[
				'label' => __( 'Spacing', 'massive-addons'),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 10,
				],
				'selectors' => [
					'{{WRAPPER}} .mae-social-icons .mae-icon' => 'margin: 0 {{SIZE}}{{UNIT}}',
					'{{WRAPPER}} .mae-social-icons .mae-icon:first-child' => 'margin-left: 0px',
					'{{WRAPPER}} .mae-social-icons .mae-icon:last-child' => 'margin-right: 0px',
					'{{WRAPPER}} .mae-social-icons-sticky-left .mae-icon, {{WRAPPER}} .mae-social-icons-sticky-right .mae-icon' => 'margin: {{SIZE}}{{UNIT}} 0',
					'{{WRAPPER}} .mae-social-icons-sticky-left .mae-icon:first-child, {{WRAPPER}} .mae-social-icons-sticky-right .mae-icon:first-child' => 'margin-top: 0px',
					'{{WRAPPER}} .mae-social-icons-sticky-left .mae-icon:last-child, {{WRAPPER}} .mae-social-icons-sticky-right .mae-icon:last-child' => 'margin-bottom: 0px',
				]
			]
		);

		$this->add_responsive_control(
			'size',
			[
				'label' => __( 'Size', 'massive-addons'),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 5,
						'max' => 100,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 32,
				],
				'selectors' => [
					'{{WRAPPER}} .mae-social-icons .svg-icon' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'width',
			[
				'label' => __( 'Width', 'massive-addons'),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 20,
				],
				'selectors' => [
					'{{WRAPPER}} .mae-social-icons .mae-icon-left' => 'padding-left: {{SIZE}}{{UNIT}}; padding-right: {{SIZE}}{{UNIT}}'
				],
			]
		);

		$this->add_responsive_control(
			'height',
			[
				'label' => __( 'Height', 'massive-addons'),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 20,
				],
				'selectors' => [
					'{{WRAPPER}} .mae-social-icons .mae-icon-left' => 'padding-top: {{SIZE}}{{UNIT}}; padding-bottom: {{SIZE}}{{UNIT}}'
				],
			]
		);

		$this->add_control(
			'border_radius',
			[
				'label' => __( 'Border Radius', 'massive-addons'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px','%'],
				'selectors' => [
					'{{WRAPPER}} .mae-social-icons .mae-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}'
				]
			]
		);

		$this->end_controls_section();

	}
    
    protected function render() {

		$settings = $this->get_settings_for_display();

		$this->add_render_attribute(
            'socialicons',
            [
                'class' => [
					'mae-social-icons',
					'mae-social-icons-' . $settings['style'] . '-style',
					'mae-icon-' . $settings['shape'],
					'mae-social-icons-inline',
					'mae-social-icons-inline-' . $settings['position'],
					$settings['full_width'],
					'mae-social-icons-' . $settings['color_scheme']
                ]
            ]
        );

		?>

		<div <?php echo $this->get_render_attribute_string('socialicons'); ?>>

			<?php foreach($settings['icons'] as $icon) { ?>

			<?php
				$target = $icon['link']['is_external'] ? ' target="_blank"' : '';
				$nofollow = $icon['link']['nofollow'] ? ' rel="nofollow"' : '';
			?>

			<a href="<?php echo $icon['link']['url']; ?>"<?php echo $target.$nofollow; ?> class="mae-icon mae-icon-<?php echo $icon['social']; ?>">
				<div class="mae-icon-left">
					<?php echo $this->render_icon($icon['social']); ?>
				</div>
			</a>

			<?php } ?>

		</div>

		<?php
        
	}
	
	protected function _content_template() {

		?>

		<#
            view.addRenderAttribute('socialicons', {
                'class': [
					'mae-social-icons',
					'mae-social-icons-' + settings.style + '-style',
					'mae-icon-' + settings.shape,
					'mae-social-icons-inline',
					'mae-social-icons-inline-' + settings.position,
					settings.full_width,
					'mae-social-icons-' + settings.color_scheme
                ],
			});
			
			var icons = {
				<?php foreach($this->render_icon() as $key => $value) { ?>
				'<?php echo $key; ?>': '<?php echo $value; ?>',
				<?php } ?>
			};

		#>
		
		<div {{{ view.getRenderAttributeString('socialicons') }}}>
		<# _.each(settings.icons, function(icon) { #>

		<#
			var target = icon.link.is_external ? ' target="_blank"' : '';
			var nofollow = icon.link.nofollow ? ' rel="nofollow"' : '';
		#>

		<a href="{{ icon.link.url }}"{{ target }}{{ nofollow }} class="mae-icon mae-icon-{{ icon.social }}">
			<div class="mae-icon-left">{{{ icons[icon.social] }}}</div>
		</a>

		<# }); #>
		</div>

		<?php

	}

	protected function render_icon($icon = "") {

		$icons = [
			'facebook' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path fill="#3E68C0" d="M5.677,12.998V8.123h3.575V6.224C9.252,2.949,11.712,0,14.736,0h3.94v4.874h-3.94 c-0.432,0-0.934,0.524-0.934,1.308v1.942h4.874v4.874h-4.874V24H9.252V12.998H5.677z"></path> </g></svg>',
			'twitter' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path id="twitter-4-icon_1_" fill="#23ABFF" d="M21.535,7.063c0.311,6.923-4.852,14.642-13.99,14.642 c-2.78,0-5.368-0.815-7.545-2.213c2.611,0.308,5.217-0.415,7.287-2.038c-2.154-0.039-3.972-1.462-4.599-3.418 c0.771,0.148,1.53,0.105,2.223-0.084c-2.367-0.475-4.002-2.608-3.948-4.888c0.664,0.369,1.423,0.59,2.229,0.615 C1.001,8.215,0.38,5.32,1.67,3.108c2.428,2.978,6.055,4.938,10.145,5.143c-0.717-3.079,1.618-6.044,4.796-6.044 c1.415,0,2.694,0.598,3.592,1.554c1.121-0.221,2.174-0.631,3.126-1.195c-0.368,1.149-1.149,2.114-2.164,2.724 c0.995-0.119,1.944-0.384,2.826-0.776C23.331,5.503,22.497,6.37,21.535,7.063z"></path> </g></svg>',
			'instagram' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <circle fill="#222222" cx="18.05" cy="5.992" r="1.355"></circle> <path fill="#222222" d="M12.021,5.806c-3.427,0-6.215,2.788-6.215,6.215s2.788,6.215,6.215,6.215s6.215-2.788,6.215-6.215 S15.448,5.806,12.021,5.806z M12.021,15.412c-1.87,0-3.391-1.521-3.391-3.391s1.521-3.391,3.391-3.391 c1.87,0,3.391,1.521,3.391,3.391S13.891,15.412,12.021,15.412z"></path> <path fill="#222222" d="M23.369,4.574c-0.357-0.919-0.846-1.669-1.539-2.362c-0.693-0.693-1.443-1.182-2.362-1.539 c-0.905-0.352-1.836-0.533-3.018-0.587c-1.153-0.053-1.536-0.065-4.43-0.065c-2.895,0-3.277,0.012-4.43,0.065 C6.409,0.14,5.478,0.321,4.574,0.673C3.655,1.03,2.904,1.519,2.212,2.212C1.519,2.904,1.03,3.655,0.673,4.573 C0.321,5.478,0.14,6.409,0.086,7.591c-0.053,1.153-0.065,1.536-0.065,4.43s0.012,3.277,0.065,4.43 c0.054,1.182,0.235,2.113,0.587,3.018c0.357,0.919,0.846,1.669,1.539,2.362c0.693,0.693,1.443,1.182,2.362,1.539 c0.905,0.352,1.836,0.533,3.018,0.587c1.153,0.053,1.536,0.065,4.43,0.065c2.895,0,3.277-0.012,4.43-0.065 c1.182-0.054,2.113-0.235,3.018-0.587c0.919-0.357,1.669-0.846,2.362-1.539c0.693-0.693,1.182-1.443,1.539-2.362 c0.352-0.905,0.533-1.836,0.587-3.018c0.053-1.153,0.065-1.536,0.065-4.43s-0.012-3.277-0.065-4.43 C23.902,6.409,23.721,5.478,23.369,4.574z M21.135,16.322c-0.05,1.105-0.239,1.715-0.398,2.123 c-0.216,0.556-0.486,0.971-0.903,1.389c-0.417,0.417-0.833,0.687-1.389,0.904c-0.408,0.159-1.018,0.347-2.123,0.397 c-1.123,0.051-1.46,0.062-4.301,0.062c-2.841,0-3.178-0.011-4.301-0.062c-1.105-0.05-1.715-0.239-2.123-0.398 c-0.556-0.216-0.971-0.486-1.389-0.903c-0.417-0.417-0.687-0.833-0.904-1.389c-0.159-0.408-0.347-1.018-0.397-2.123 c-0.051-1.123-0.062-1.46-0.062-4.301s0.011-3.178,0.062-4.301c0.05-1.105,0.239-1.715,0.398-2.123 c0.216-0.556,0.486-0.971,0.903-1.389c0.417-0.417,0.833-0.687,1.389-0.904C6.005,3.146,6.615,2.957,7.72,2.907 c1.123-0.051,1.46-0.062,4.301-0.062c2.841,0,3.178,0.011,4.302,0.062c1.105,0.05,1.715,0.239,2.123,0.398 c0.556,0.216,0.971,0.486,1.389,0.903c0.417,0.417,0.687,0.833,0.904,1.389c0.159,0.408,0.347,1.018,0.397,2.123 c0.051,1.123,0.062,1.46,0.062,4.301S21.186,15.199,21.135,16.322z"></path> </g></svg>',
			'email' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path fill="#0874C1" d="M23.674,3.741c-0.338-0.495-0.907-0.823-1.549-0.823H1.876c-0.629,0-1.184,0.316-1.525,0.794l11.687,9.745 L23.674,3.741z"></path> <path fill="#0874C1" d="M12.037,16.409L0,6.371v12.836c0,1.031,0.844,1.875,1.875,1.875h20.249c1.031,0,1.875-0.844,1.875-1.875 V6.421L12.037,16.409z"></path> </g></svg>',
			'500px' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path fill="#0099E5" d="M23.3,11.089c-0.688-1.059-1.814-1.642-3.172-1.642c-1.738,0-3.318,1.37-4.253,2.39 c-0.935-1.02-2.514-2.39-4.252-2.39c-1.358,0-2.485,0.583-3.172,1.642c-0.192,0.296-0.336,0.607-0.441,0.909 c-0.495-1.259-1.582-2.13-3.158-2.13c-0.897,0-1.571,0.241-2.196,0.866l-0.032-0.032l0.449-2.549h4.632V6.278H1.438L0.332,12.48 h2.051c0.449-0.625,0.898-0.898,1.715-0.898c1.218,0,1.939,0.93,1.939,2.1c0,1.122-0.753,2.163-1.939,2.163 c-1.01,0-1.731-0.673-1.843-1.683h-2.276c0.049,2.356,1.988,3.558,4.167,3.558c1.74,0.037,3.287-1.025,3.894-2.579 c0.052,0.152,0.113,0.307,0.188,0.459c0.612,1.252,1.817,1.943,3.394,1.942c1.739,0,3.318-1.37,4.252-2.389 c0.935,1.02,2.515,2.389,4.253,2.389c0,0,0,0,0,0c1.577,0,2.782-0.69,3.394-1.942c0.456-0.934,0.456-1.923,0.456-2.296v-0.009 C23.979,12.734,23.801,11.859,23.3,11.089z M15.878,13.496l-0.001,0.001l-0.002-0.001l0.001-0.001L15.878,13.496z M11.623,15.423 c-0.994,0-1.318-0.402-1.489-0.753c-0.241-0.494-0.241-1.104-0.241-1.364v-0.009c0-0.139,0.062-0.629,0.337-1.053 c0.299-0.461,0.742-0.676,1.393-0.676c0.927,0,2.106,1.018,2.893,1.927C13.729,14.405,12.55,15.423,11.623,15.423z M21.859,13.306 c0,0.26,0,0.871-0.241,1.364c-0.171,0.351-0.495,0.753-1.489,0.753c-0.927,0-2.106-1.018-2.893-1.928 c0.787-0.909,1.966-1.927,2.893-1.927c0.651,0,1.094,0.215,1.394,0.676c0.275,0.423,0.336,0.914,0.336,1.053V13.306z"></path> </g></svg>',
			'behance' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <g> <rect x="15.101" y="5.466" fill="#1776F6" width="6.476" height="1.505"></rect> <path fill="#1776F6" d="M9.923,11.516c0.501-0.256,0.88-0.539,1.137-0.849c0.46-0.553,0.69-1.284,0.69-2.195 c0-0.883-0.228-1.641-0.684-2.275C10.308,5.166,9.02,4.637,7.203,4.61H0v14.905h6.716c0.757,0,1.459-0.068,2.106-0.203 c0.646-0.134,1.209-0.384,1.684-0.748c0.422-0.317,0.774-0.708,1.056-1.173c0.443-0.701,0.664-1.493,0.664-2.377 c0-0.856-0.194-1.584-0.581-2.184C11.258,12.231,10.684,11.793,9.923,11.516z M2.973,7.199h3.242c0.714,0,1.301,0.077,1.761,0.233 C8.51,7.654,8.777,8.112,8.777,8.806c0,0.627-0.202,1.063-0.605,1.31c-0.404,0.246-0.929,0.369-1.576,0.369H2.973V7.199z M8.101,16.663c-0.36,0.176-0.863,0.263-1.51,0.263H2.973v-3.974h3.669c0.64,0.007,1.136,0.091,1.489,0.253 c0.633,0.29,0.95,0.823,0.95,1.598C9.081,15.72,8.754,16.34,8.101,16.663z"></path> <path fill="#1776F6" d="M23.902,12.626c-0.134-0.865-0.427-1.624-0.878-2.279c-0.5-0.743-1.136-1.286-1.905-1.63 C20.351,8.372,19.486,8.2,18.527,8.2c-1.615,0-2.929,0.509-3.941,1.528c-1.013,1.019-1.518,2.483-1.518,4.392 c0,2.038,0.56,3.509,1.682,4.412c1.122,0.905,2.415,1.357,3.882,1.357c1.777,0,3.16-0.536,4.146-1.608 c0.635-0.674,0.991-1.338,1.068-1.992h-2.942c-0.172,0.323-0.369,0.577-0.594,0.758c-0.41,0.337-0.943,0.505-1.6,0.505 c-0.619,0-1.149-0.138-1.589-0.414c-0.724-0.444-1.108-1.22-1.153-2.325h8.028C24.011,13.861,23.98,13.132,23.902,12.626z M16.041,12.912c0.105-0.718,0.36-1.286,0.767-1.706c0.407-0.42,0.981-0.63,1.72-0.63c0.68,0,1.25,0.198,1.709,0.594 c0.459,0.396,0.716,0.976,0.768,1.742H16.041z"></path> </g> </g></svg>',
			'badoo' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <g> <path fill="#FF6719" d="M21.191,11.287c-0.695-2.374-2.401-4.394-4.535-5.617c-2.437-1.402-5.496-1.544-8.114-0.575 c-1.324,0.53-2.521,1.358-3.504,2.39C5.021,5.361,5.037,3.236,5.029,1.111c0.003-0.413-0.25-0.824-0.639-0.978 C3.941-0.048,3.416-0.044,2.971,0.146C2.596,0.308,2.362,0.708,2.355,1.11c-0.02,2.159,0.03,4.318,0.017,6.476 c-0.013,2.338,0.03,4.674,0.019,7.012c0.054,1.318,0.351,2.633,0.901,3.834c0.974,2.079,2.71,3.792,4.805,4.73 c1.765,0.751,3.75,1.055,5.642,0.67c2.317-0.405,4.443-1.718,5.871-3.581c1.349-1.731,2.016-3.933,2.039-6.114 C21.62,13.174,21.47,12.212,21.191,11.287z M18.902,15.286c-0.219,1.54-0.973,2.997-2.1,4.07c-0.987,0.99-2.296,1.645-3.677,1.86 c-1.592,0.264-3.277-0.057-4.66-0.891c-0.729-0.448-1.371-1.032-1.914-1.693c-1.914-2.357-2.029-5.998-0.254-8.462 c0.572-0.758,1.244-1.455,2.058-1.953c0.86-0.542,1.848-0.868,2.857-0.985c1.683-0.197,3.449,0.223,4.825,1.225 c1.03,0.773,1.886,1.8,2.392,2.99C18.923,12.651,19.119,13.995,18.902,15.286z"></path> <path fill="#FF6719" d="M8.093,12.135c-0.664,0.014-1.37,0.313-1.713,0.908c-0.225,0.4-0.362,0.872-0.287,1.332 c0.091,0.506,0.308,1.016,0.725,1.337c0.565,0.433,1.366,0.57,2.021,0.262c0.659-0.258,1.055-0.927,1.15-1.606 c0.072-0.507-0.081-1.036-0.371-1.453C9.28,12.421,8.678,12.162,8.093,12.135z"></path> </g> </g></svg>',
			'blogger' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path id="Blogger_3_" fill="#FF8B13" d="M16.356,24.011c4.184,0,7.584-3.409,7.607-7.571l0.046-6.128l-0.07-0.333L23.739,9.56 l-0.34-0.263C22.958,8.95,20.72,9.32,20.117,8.773c-0.427-0.39-0.493-1.096-0.623-2.052c-0.24-1.851-0.391-1.948-0.682-2.576 C17.759,1.917,14.9,0.242,12.936,0.01H7.617c-4.186,0-7.607,3.414-7.607,7.583v8.847c0,4.162,3.422,7.571,7.607,7.571H16.356z M7.714,6.205h4.217c0.806,0,1.458,0.654,1.458,1.448c0,0.792-0.652,1.451-1.458,1.451H7.714c-0.805,0-1.456-0.659-1.456-1.451 C6.258,6.859,6.909,6.205,7.714,6.205z M6.258,16.328c0-0.795,0.651-1.443,1.456-1.443h8.569c0.8,0,1.45,0.648,1.45,1.443 c0,0.784-0.65,1.442-1.45,1.442H7.714C6.909,17.77,6.258,17.112,6.258,16.328z"></path> </g></svg>',
			'delicious' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path fill="#3399FF" d="M18.667,2H5.333C3.5,2,2,3.5,2,5.334v13.332C2,20.502,3.5,22,5.333,22h13.334 C20.501,22,22,20.501,22,18.667V5.334C22.001,3.5,20.502,2,18.667,2z M20.751,18.667c0,0.553-0.218,1.076-0.613,1.471 c-0.395,0.395-0.917,0.613-1.47,0.613h-6.668V12h-8.75V5.334c0-0.552,0.217-1.075,0.613-1.471C4.259,3.467,4.782,3.25,5.335,3.25 h6.667V12h8.75L20.751,18.667L20.751,18.667z"></path> </g></svg>',
			'deviantart' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <polygon id="da_1_" fill="#05CC47" points="19.487,4.404 14.845,13.301 19.487,13.301 19.487,19.18 11.787,19.18 9.273,24 4.513,24 4.513,20.081 9.372,10.768 4.513,10.768 4.513,4.83 12.47,4.83 14.994,0 19.487,0 	"></polygon> </g></svg>',
			'digg' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <g> <path fill="#222222" d="M3.61,5.166v3.18H0v7.278h5.956V5.166H3.61z M3.61,13.667H2.387v-3.308H3.61V13.667z"></path> <path fill="#222222" d="M10.848,8.376v7.278h3.612v1.138h-3.653v2.043h4.964h1.036V8.376H10.848z M14.46,13.64h-1.225v-3.309 h1.225V13.64z"></path> <path fill="#222222" d="M18.044,8.376v7.278h3.609v1.138H18v2.043h4.965H24V8.376H18.044z M21.653,13.64h-1.221v-3.309h1.221 V13.64z"></path> <rect x="7.166" y="8.331" fill="#222222" width="2.431" height="7.323"></rect> <rect x="7.166" y="5.295" fill="#222222" width="2.431" height="1.985"></rect> </g> </g></svg>',
			'disqus' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <g> <path fill="#3CA2EF" d="M12.436,23.625c-2.851,0-5.459-1.038-7.475-2.758L0,21.542l1.916-4.719 C1.248,15.352,0.874,13.721,0.874,12c0-6.42,5.177-11.625,11.562-11.625C18.823,0.375,24,5.58,24,12S18.823,23.625,12.436,23.625z M18.751,11.967v-0.032c0-3.354-2.373-5.746-6.461-5.746H7.873v11.625h4.352C16.344,17.813,18.751,15.319,18.751,11.967 L18.751,11.967z M12.339,14.956h-1.292v-5.91h1.292c1.897,0,3.156,1.078,3.156,2.939v0.033 C15.494,13.894,14.236,14.956,12.339,14.956z"></path> </g> </g></svg>',
			'dribbble' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path id="dribbble-icon_2_" fill="#FA488C" d="M12,0C5.373,0,0,5.373,0,12c0,6.627,5.373,12,12,12c6.627,0,12-5.373,12-12 C24,5.373,18.627,0,12,0z M21.885,11.441c-2.575-0.422-4.943-0.445-7.102-0.073c-0.244-0.563-0.497-1.124-0.766-1.68 c2.309-1,4.165-2.358,5.547-4.082C20.913,7.2,21.76,9.225,21.885,11.441z M18.043,4.159c-1.204,1.553-2.868,2.783-4.986,3.68 c-1.016-1.861-2.177-3.676-3.488-5.437C10.348,2.204,11.16,2.087,12,2.087C14.274,2.087,16.367,2.865,18.043,4.159z M7.528,3.165 c1.331,1.743,2.511,3.538,3.537,5.381C8.634,9.262,5.733,9.63,2.38,9.652C3.072,6.817,4.982,4.459,7.528,3.165z M2.088,12 c0-0.086,0.01-0.17,0.013-0.256c3.848-0.006,7.168-0.448,9.949-1.322c0.234,0.475,0.457,0.952,0.67,1.432 c-3.379,1.056-6.165,3.221-8.336,6.48C2.951,16.616,2.088,14.407,2.088,12z M5.916,19.81c1.969-3.088,4.482-5.098,7.598-6.028 c0.927,2.42,1.609,4.91,2.042,7.46C14.45,21.67,13.254,21.913,12,21.913C9.706,21.913,7.598,21.123,5.916,19.81z M17.502,20.24 c-0.438-2.353-1.08-4.653-1.92-6.898c1.875-0.264,3.94-0.196,6.198,0.197C21.344,16.325,19.753,18.732,17.502,20.24z"></path> </g></svg>',
			'envato' => '<svg viewBox="0 0 24 24" class="svg-icon"><g id="_x31__stroke"> <g id="Envato_1_"> <path id="Envato" fill="#8DCF3A" d="M19.304,0.131c1.075,0.527,5.448,9.964,1.717,18.184c-2.996,6.6-10.517,6.601-14.33,4.275 C3.434,20.603-1.54,14.341,3.967,6.694C4.2,6.405,4.759,6.431,4.633,7.307C4.544,7.93,3.745,12.399,5.27,14.341 c0.696,0.971,0.859,0.302,0.859,0.302S6.01,8.14,10.955,3.203C14.093,0.191,18.445-0.291,19.304,0.131"></path> </g> </g></svg>',
			'evernote' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <g> <path fill-rule="evenodd" clip-rule="evenodd" fill="#2DBE60" d="M6.676,0.728C5.63,1.837,4.502,2.864,3.46,3.977 C3.17,4.166,2.885,4.52,2.647,4.757C2.574,4.831,2.349,4.957,2.46,5.007c0.843-0.583,2.623-0.229,3.905-0.375 c0.158-0.194,0.074-0.454,0.062-0.718c-0.029-0.686-0.058-1.588,0-2.249C6.461,1.274,6.627,0.998,6.676,0.728z"></path> <path fill-rule="evenodd" clip-rule="evenodd" fill="#2DBE60" d="M2.242,9.63c0.23,1.473,0.491,2.894,0.874,4.247 c0.189,0.667,0.405,1.392,0.812,1.75c0.374,0.328,1.052,0.49,1.656,0.655c1.189,0.327,2.081,0.519,3.467,0.719 c0.518,0.074,1.266,0.35,1.843,0.125c0.551-0.215,0.748-1.095,0.906-1.749c0.133-0.554,0.224-1.147,0.25-1.718 c0.01-0.221-0.08-0.52,0.094-0.594c0.067,1.398,0.153,2.287,1.062,2.78c0.402,0.218,1.1,0.366,1.811,0.468 c0.707,0.102,1.485,0.103,1.968,0.312c0.804,0.349,0.982,1.22,1.062,2.374c0.056,0.81,0.133,1.842-0.406,2.249 c-0.366,0.277-1.142,0.281-1.936,0.281c-0.81,0-1.456-0.049-1.656-0.437c-0.191-0.37-0.135-1.019,0.062-1.25 c0.324-0.377,1.016-0.212,1.593-0.312c-0.016-0.292-0.085-0.573-0.063-0.875c0.021-0.282,0.17-0.531,0.125-0.749 c-1.425-0.112-2.803-0.046-3.373,0.749c-0.651,0.908-0.646,3.284-0.062,4.217c0.649,1.037,2.285,1.101,3.811,1.125 c1.154,0.017,2.531-0.065,3.217-0.625c0.651-0.532,1.077-1.457,1.406-2.436c0.679-2.024,0.967-4.058,1.187-6.465 c0.112-1.219,0.032-2.476,0-3.717c-0.043-1.68-0.169-3.729-0.343-5.403c-0.066-0.626-0.121-1.247-0.281-1.656 c-0.374-0.955-1.252-1.204-2.374-1.406C17.336,2,15.628,1.835,13.829,1.915c-0.248-1.165-0.932-1.578-2.186-1.78 C9.994-0.131,7.88-0.105,7.333,1.165C7.074,1.764,7.208,2.518,7.208,3.352c0,0.488,0.098,1.091-0.063,1.468 c-0.373,0.873-1.927,0.399-3.311,0.5C3.509,5.343,3.08,5.444,2.804,5.601C1.622,6.271,2.015,8.183,2.242,9.63z M16.484,10.192 c0.361-0.283,0.972-0.312,1.375-0.094c0.47,0.254,0.642,0.931,0.655,1.593c-0.706-0.261-1.636-0.417-2.561-0.281 C16.057,10.879,16.158,10.448,16.484,10.192z"></path> </g> </g></svg>',
			'fb-messenger' => '<svg viewBox="0 0 24 24" class="svg-icon"><path id="Facebook_Messenger" fill="#007FFF" d="M13.192,14.963l-3.056-3.259l-5.963,3.259L10.732,8l3.13,3.259L19.75,8 L13.192,14.963z M12,0C5.373,0,0,4.975,0,11.111c0,3.497,1.745,6.616,4.472,8.652V24l4.086-2.242 c1.09,0.302,2.246,0.465,3.442,0.465c6.627,0,12-4.975,12-11.111C24,4.974,18.627,0,12,0z"></path></svg>',
			'flickr' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <g> <path fill="#FF0084" d="M24,12c0,2.92-2.365,5.287-5.285,5.287c-2.924,0-5.289-2.367-5.289-5.287c0-2.919,2.365-5.286,5.289-5.286 C21.635,6.714,24,9.082,24,12z"></path> <path fill="#FF0084" d="M10.573,12c0,2.92-2.365,5.287-5.289,5.287C2.365,17.286,0,14.919,0,12c0-2.919,2.365-5.286,5.284-5.286 C8.208,6.714,10.573,9.082,10.573,12z"></path> </g> </g></svg>',
			'flipboard' => '<svg viewBox="0 0 24 24" class="svg-icon"><path fill="#F43D3D" d="M2,2c0,0,13.333,0,20,0c0,2.213,0,4.427,0,6.64c-2.213,0-4.427,0-6.641,0c0,2.213,0,4.427,0,6.641 c-2.213,0-4.427,0-6.641,0c0,2.239,0,4.479,0,6.718C6.479,22,4.239,22,2,22C2,15.333,2,8.641,2,8.641V2z"></path></svg>',
			'forrst' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <g> <polygon fill="#55C462" points="11.973,0 3.1,21.268 11.036,21.268 11.036,16.757 8.864,15.269 9.204,14.763 11.036,16.015 11.036,12.457 12.983,12.457 12.983,14.733 14.772,13.789 15.076,14.349 12.983,15.456 12.983,17.093 16.336,15.414 16.604,15.956 12.983,17.769 12.983,21.268 20.845,21.268 		"></polygon> <rect x="11.036" y="21.268" fill="#55C462" width="1.947" height="2.732"></rect> </g> </g></svg>',
			'foursquare' => '<svg viewBox="0 0 24 24" class="svg-icon"><path id="Foursquare" fill="#FF3B6F" d="M18.412,0H5.758C4.02,0,3.5,1.331,3.5,2.168v20.334c0,1.002,0.504,1.298,0.78,1.412 c0.276,0.115,1.007,0.197,1.527-0.328c0,0,6.01-7.079,6.107-7.194s0.146-0.115,0.211-0.115h3.801c1.624,0,1.933-1.133,2.112-1.823 c0.146-0.575,1.819-8.787,2.339-11.382C20.767,1.068,20.264,0,18.412,0 M17.665,3.466l-0.568,2.776 C17.032,6.538,16.756,6.8,16.415,6.8h-4.938c-0.552,0-1.007,0.46-1.007,1.018v0.608c0,0.558,0.455,1.018,1.007,1.018h4.174 c0.39,0,0.715,0.378,0.634,0.788c-0.081,0.427-0.52,2.595-0.568,2.825c-0.032,0.246-0.292,0.558-0.682,0.558h-3.411 c-0.715,0.016-0.861,0.033-1.283,0.558c-0.422,0.526-4.158,5.256-4.158,5.256c-0.032,0.049-0.065,0.033-0.065-0.017V3.332 c0-0.378,0.309-0.69,0.682-0.69h10.25C17.405,2.645,17.762,3.006,17.665,3.466"></path></svg>',
			'github' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path fill="#222222" d="M22.389,6.269c-1.073-1.839-2.529-3.294-4.367-4.367c-1.839-1.073-3.846-1.609-6.023-1.609 S7.814,0.83,5.977,1.902C4.137,2.975,2.682,4.431,1.609,6.269c-1.073,1.839-1.609,3.846-1.609,6.023 c0,2.615,0.763,4.966,2.289,7.055c1.526,2.089,3.497,3.534,5.914,4.336c0.281,0.052,0.49,0.015,0.625-0.109 c0.135-0.125,0.203-0.281,0.203-0.469c0-0.031-0.003-0.312-0.008-0.844c-0.005-0.531-0.008-0.995-0.008-1.39l-0.359,0.062 c-0.229,0.042-0.518,0.06-0.867,0.055s-0.711-0.041-1.086-0.109c-0.375-0.067-0.724-0.224-1.047-0.468 c-0.323-0.245-0.552-0.565-0.687-0.961l-0.156-0.36c-0.104-0.239-0.268-0.505-0.492-0.797c-0.224-0.292-0.451-0.49-0.68-0.594 l-0.109-0.078c-0.073-0.052-0.141-0.115-0.203-0.188s-0.109-0.146-0.141-0.219c-0.031-0.073-0.005-0.133,0.078-0.18 c0.083-0.047,0.234-0.07,0.453-0.07l0.312,0.047c0.208,0.042,0.466,0.166,0.773,0.375c0.307,0.208,0.56,0.479,0.758,0.812 c0.24,0.427,0.528,0.753,0.867,0.977c0.338,0.224,0.68,0.336,1.023,0.336c0.344,0,0.641-0.026,0.891-0.078s0.484-0.13,0.703-0.234 c0.094-0.698,0.349-1.235,0.766-1.609c-0.594-0.062-1.127-0.156-1.602-0.281c-0.474-0.125-0.963-0.328-1.469-0.61 c-0.505-0.281-0.925-0.63-1.258-1.047c-0.333-0.417-0.607-0.964-0.82-1.641c-0.213-0.677-0.32-1.458-0.32-2.344 c0-1.261,0.412-2.333,1.234-3.219c-0.385-0.948-0.349-2.01,0.109-3.187c0.302-0.094,0.75-0.023,1.344,0.211S8.06,5.908,8.335,6.075 c0.276,0.166,0.497,0.307,0.664,0.422c0.969-0.271,1.969-0.406,3-0.406s2.031,0.135,3,0.406l0.594-0.375 c0.406-0.25,0.885-0.479,1.437-0.688c0.552-0.208,0.974-0.266,1.266-0.172c0.469,1.177,0.51,2.24,0.125,3.187 c0.823,0.885,1.235,1.958,1.235,3.219c0,0.885-0.107,1.669-0.32,2.351c-0.213,0.682-0.489,1.229-0.828,1.641 s-0.761,0.758-1.266,1.039s-0.995,0.484-1.469,0.609s-1.008,0.219-1.601,0.282c0.541,0.469,0.812,1.208,0.812,2.219v3.297 c0,0.187,0.065,0.344,0.195,0.469s0.336,0.161,0.617,0.109c2.417-0.802,4.388-2.247,5.914-4.336 c1.526-2.088,2.289-4.44,2.289-7.055C23.999,10.115,23.462,8.108,22.389,6.269z"></path> </g></svg>',
			'google-plus' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path fill="#F63329" d="M7.636,10.929V13.5h4.331c-0.175,1.104-1.309,3.236-4.331,3.236c-2.607,0-4.735-2.121-4.735-4.736 s2.127-4.736,4.735-4.736c1.484,0,2.476,0.621,3.044,1.157l2.073-1.961C11.422,5.239,9.698,4.5,7.636,4.5C3.415,4.5,0,7.854,0,12 s3.415,7.5,7.636,7.5c4.407,0,7.331-3.043,7.331-7.329c0-0.493-0.055-0.868-0.12-1.243H7.636z"></path> <path fill="#F63329" d="M21.818,10.929V8.786h-2.182v2.143h-2.182v2.143h2.182v2.143h2.182v-2.143H24c0,0.022,0-2.143,0-2.143 H21.818z"></path> </g></svg>',
			'lastfm' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <g> <path fill="#EA3939" d="M7.39,4.81c-0.893,0-1.766,0.166-2.593,0.493c-3.69,1.457-5.507,5.645-4.049,9.334 c1.092,2.766,3.722,4.552,6.699,4.552c0.903,0,1.789-0.169,2.635-0.503c1.013-0.4,1.899-1.007,2.635-1.803l-1.006-2.22 c-0.309,0.397-1.069,1.295-2.454,1.916c-0.522,0.234-1.114,0.347-1.811,0.347c-2.042,0-3.846-1.224-4.594-3.12 c-0.999-2.529,0.247-5.399,2.776-6.399C6.19,7.186,6.784,7.073,7.393,7.073c2.022,0,3.915,1.263,4.711,3.143l0.181,0.426 c1.548,3.658,2.452,5.765,3.031,6.513c1.024,1.324,2.33,1.967,3.993,1.967c2.94,0,4.72-1.994,4.903-3.871 c0.203-2.084-0.547-3.419-2.294-4.083c-0.519-0.197-0.965-0.337-1.396-0.473c-0.148-0.047-0.29-0.089-0.429-0.131 c-0.756-0.225-1.41-0.42-2.024-1.014c-0.252-0.244-0.353-0.647-0.27-1.077c0.034-0.178,0.25-1.077,1.156-1.316 c0.212-0.056,0.419-0.084,0.616-0.084c1.057,0,1.721,0.673,1.799,0.797l0.036,0.057c0.078,0.123,0.158,0.249,0.243,0.447 l1.812-1.201c-0.033-0.091-0.092-0.191-0.183-0.305l-0.025-0.034c-0.332-0.474-1.58-2.022-3.692-2.022 c-0.388,0-0.787,0.053-1.185,0.158c-1.434,0.379-2.507,1.557-2.8,3.075c-0.259,1.343,0.183,2.62,1.154,3.333 c1.051,0.771,2.965,1.421,3.782,1.699c0.166,0.056,0.293,0.1,0.367,0.128c0.86,0.327,1.173,0.857,1.078,1.828 c-0.069,0.706-0.849,1.827-2.651,1.827c-0.966,0-1.605-0.315-2.203-1.089c-0.427-0.553-1.708-3.579-2.737-6.011l-0.181-0.428 C13.024,6.586,10.356,4.81,7.39,4.81z"></path> </g> </g></svg>',
			'line' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path fill="#00c300" d="M24,10.3c0-5.4-5.4-9.7-12-9.7c-6.6,0-12,4.4-12,9.7c0,4.8,4.3,8.8,10,9.6c0.4,0.1,0.9,0.3,1.1,0.6 c0.1,0.3,0.1,0.8,0,1.1c0,0-0.1,0.8-0.2,1c-0.1,0.3-0.2,1.2,1,0.6c1.3-0.5,6.9-4.1,9.4-7h0C23.1,14.4,24,12.5,24,10.3z M7.7,13.2 c0,0.1-0.1,0.2-0.2,0.2H4.1h0c-0.1,0-0.1,0-0.2-0.1c0,0,0,0,0,0c0,0,0,0,0,0c0,0-0.1-0.1-0.1-0.2v0V7.9c0-0.1,0.1-0.2,0.2-0.2H5 c0.1,0,0.2,0.1,0.2,0.2v4.2h2.3c0.1,0,0.2,0.1,0.2,0.2V13.2z M9.8,13.2c0,0.1-0.1,0.2-0.2,0.2H8.7c-0.1,0-0.2-0.1-0.2-0.2V7.9 c0-0.1,0.1-0.2,0.2-0.2h0.8c0.1,0,0.2,0.1,0.2,0.2V13.2z M15.6,13.2c0,0.1-0.1,0.2-0.2,0.2h-0.8c0,0,0,0-0.1,0c0,0,0,0,0,0 c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0-0.1-0.1l-2.4-3.2v3.1 c0,0.1-0.1,0.2-0.2,0.2h-0.8c-0.1,0-0.2-0.1-0.2-0.2V7.9c0-0.1,0.1-0.2,0.2-0.2h0.8c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0 c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0 c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0,0,0,0l2.4,3.2V7.9c0-0.1,0.1-0.2,0.2-0.2h0.8 c0.1,0,0.2,0.1,0.2,0.2V13.2z M20.2,8.8C20.2,8.9,20.1,9,20,9h-2.3v0.9H20c0.1,0,0.2,0.1,0.2,0.2V11c0,0.1-0.1,0.2-0.2,0.2h-2.3 v0.9H20c0.1,0,0.2,0.1,0.2,0.2v0.8c0,0.1-0.1,0.2-0.2,0.2h-3.4h0c-0.1,0-0.1,0-0.2-0.1c0,0,0,0,0,0c0,0,0,0,0,0 c0,0-0.1-0.1-0.1-0.2v0V7.9v0c0-0.1,0-0.1,0.1-0.2c0,0,0,0,0,0c0,0,0,0,0,0c0,0,0.1-0.1,0.2-0.1h0H20c0.1,0,0.2,0.1,0.2,0.2V8.8z"></path> </g></svg>',
			'lineat' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path fill="#00c300" d="M12,0C5.4,0,0,5.4,0,12s5.4,12,12,12c1.3,0,2.5-0.2,3.7-0.6l0.7-0.3c0.3-0.1,0.4-0.4,0.3-0.6 l-0.7-2.1c-0.1-0.2-0.3-0.4-0.6-0.3l-0.7,0.3c-0.9,0.3-1.8,0.4-2.7,0.4c-4.9,0-8.8-4-8.8-8.8s4-8.8,8.8-8.8c4.9,0,8.8,4,8.8,8.8 c0,1-0.2,2-0.6,3.1c-0.3,0.8-0.9,1.4-1.4,1.4c-0.7,0-1.2-0.6-1.2-1.2V6.8c0-0.3-0.2-0.5-0.5-0.5h-2.2c-0.3,0-0.5,0.2-0.5,0.5 l0,0.2l-0.2-0.1c-0.8-0.5-1.8-0.7-2.8-0.7c-3.2,0-5.9,2.6-5.9,5.9s2.6,5.9,5.9,5.9c1.1,0,2.2-0.3,3.1-0.9l0.1-0.1l0.1,0.1 c0.7,1.6,2.3,2.7,4.1,2.7c1.9,0,3.7-1.4,4.4-3.5c0.5-1.4,0.7-2.8,0.7-4.1C24,5.4,18.6,0,12,0z M14.4,12c0,1.6-1.3,2.9-2.9,2.9 S8.6,13.6,8.6,12s1.3-2.9,2.9-2.9S14.4,10.4,14.4,12z"></path> </g></svg>',
			'linkedin' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path id="linkedin-square-rounded-icon_2_" fill="#15ACE5" d="M6.52,22h-4.13V8.667h4.13V22z M4.436,6.92 c-1.349,0-2.442-1.101-2.442-2.46C1.994,3.102,3.087,2,4.436,2s2.442,1.102,2.442,2.46C6.877,5.819,5.784,6.92,4.436,6.92z M21.994,22h-4.109c0,0,0-5.079,0-6.999c0-1.919-0.73-2.991-2.249-2.991c-1.652,0-2.515,1.116-2.515,2.991c0,2.054,0,6.999,0,6.999 h-3.96V8.667h3.96v1.796c0,0,1.191-2.202,4.02-2.202c2.828,0,4.853,1.727,4.853,5.298C21.994,17.129,21.994,22,21.994,22z"></path> </g></svg>',
			'livejournal' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path fill="#2CBAE5" d="M17.418,11.6l0.816,3.418l0.837,3.854l-3.894-0.829l-3.456-0.805L2.394,8.01 c-0.688,1.448-1.075,3.063-1.075,4.769C1.319,18.976,6.396,24,12.66,24C18.923,24,24,18.976,24,12.779S18.923,1.557,12.66,1.557 c-1.587,0-3.097,0.324-4.469,0.906l9.227,9.129C17.417,11.593,17.421,11.598,17.418,11.6z"></path> <path fill="#2CBAE5" d="M17.6,14.792l-0.608-2.642c-2.093,0.951-3.752,2.592-4.712,4.664l2.67,0.602 C15.516,16.294,16.467,15.353,17.6,14.792z"></path> <path fill="#2CBAE5" d="M8.191,2.464L5.701,0C3.384,1.417,1.433,3.349,0,5.641L2.394,8.01C3.573,5.531,5.64,3.548,8.191,2.464z"></path> </g></svg>',
			'myspace' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path fill="#222222" d="M3.354,13.528c0.828,0,1.578-0.333,2.12-0.874c0.541-0.539,0.875-1.284,0.875-2.111 c0-0.825-0.335-1.571-0.876-2.112C4.931,7.89,4.181,7.556,3.354,7.556c-0.823,0-1.57,0.335-2.112,0.876 c-0.541,0.541-0.876,1.287-0.876,2.111c0,0.826,0.334,1.571,0.873,2.11C1.781,13.194,2.529,13.528,3.354,13.528z"></path> <path fill="#222222" d="M11.181,12.962c0.931,0,1.775-0.379,2.386-0.99s0.99-1.455,0.99-2.386c0-0.934-0.378-1.777-0.987-2.387 c-0.611-0.611-1.456-0.988-2.389-0.988c-1.871,0-3.376,1.505-3.376,3.375c0,0.932,0.377,1.777,0.989,2.388 C9.404,12.584,10.246,12.962,11.181,12.962z"></path> <path fill="#222222" d="M19.846,12.17c1.028,0,1.96-0.421,2.633-1.1c0.675-0.68,1.092-1.62,1.092-2.658 c0-1.042-0.418-1.986-1.093-2.669c-0.674-0.681-1.604-1.103-2.633-1.103c-1.032,0-1.966,0.422-2.641,1.104 C16.528,6.427,16.11,7.37,16.11,8.412c0,1.038,0.418,1.978,1.095,2.659C17.88,11.749,18.813,12.17,19.846,12.17z"></path> <path fill="#222222" d="M22.822,14.67c-0.73-0.769-1.754-1.261-2.931-1.261H19.89c-1.046,0-2.145,0.451-2.945,1.268 c-0.701,0.715-1.171,1.714-1.171,2.938v1.615c0,0.047,0.011,0.082,0.029,0.1c0.019,0.019,0.054,0.029,0.103,0.029h7.946 c0.053,0,0.091-0.011,0.111-0.031c0.018-0.017,0.028-0.051,0.028-0.098v-1.615v-0.001h0.001 C23.991,16.495,23.554,15.442,22.822,14.67z"></path> <path fill="#222222" d="M13.754,15.182c-0.635-0.648-1.52-1.076-2.581-1.076c-0.975,0-1.902,0.416-2.575,1.113 c-0.644,0.667-1.056,1.592-1.056,2.658v1.353c0,0.048,0.011,0.082,0.029,0.1c0.019,0.019,0.055,0.03,0.103,0.03h7.049 c0.048,0,0.083-0.011,0.103-0.03c0.018-0.018,0.029-0.052,0.029-0.1l0.001-0.001l0.007-1.352h-0.001 C14.861,16.895,14.459,15.903,13.754,15.182z"></path> <path fill="#222222" d="M3.323,14.597c-0.935,0-1.723,0.396-2.295,0.983c-0.647,0.664-1.019,1.571-1.019,2.43v1.211 c0,0.048,0.012,0.083,0.033,0.104c0.021,0.021,0.057,0.034,0.104,0.034h6.348c0.049,0,0.085-0.011,0.105-0.031l0.001-0.001 c0.02-0.02,0.031-0.056,0.031-0.105v-1.211l0,0c0-0.943-0.373-1.796-0.973-2.413C5.058,14.979,4.23,14.597,3.323,14.597z"></path> </g></svg>',
			'odnoklassniki' => '<svg viewBox="0 0 24 24" class="svg-icon"><path fill="#FF8321" d="M11.984,12.244c3.381,0,6.122-2.741,6.122-6.122S15.365,0,11.984,0S5.863,2.741,5.863,6.122 S8.604,12.244,11.984,12.244z M11.984,3.673c1.352,0,2.449,1.096,2.449,2.449S13.337,8.57,11.984,8.57S9.536,7.474,9.536,6.122 C9.537,4.77,10.633,3.675,11.984,3.673z"></path> <path fill="#FF8321" d="M14.224,17.201c1.366-0.261,2.673-0.769,3.856-1.499c0.804-0.499,1.052-1.556,0.553-2.36 c-0.499-0.804-1.556-1.052-2.36-0.553c-0.003,0.002-0.007,0.004-0.01,0.006c-2.581,1.573-5.817,1.603-8.427,0.078 c-0.815-0.482-1.867-0.212-2.349,0.603c-0.478,0.808-0.218,1.849,0.584,2.337c1.136,0.671,2.379,1.14,3.674,1.388l-3.87,3.87 c-0.671,0.668-0.672,1.754-0.004,2.424s1.754,0.672,2.424,0.004c0.002-0.002,0.003-0.003,0.005-0.005l3.685-3.685l3.685,3.685 c0.668,0.671,1.753,0.673,2.424,0.005c0.671-0.668,0.673-1.753,0.005-2.424c-0.001-0.001-0.003-0.003-0.004-0.004L14.224,17.201z"></path></svg>',
			'periscope' => '<svg viewBox="0 0 24 24" class="svg-icon"><path id="Periscope_1_" fill="#35B3DB" d="M12.001,3.717c-0.445,0-0.877,0.054-1.292,0.153c0.752,0.374,1.272,1.155,1.272,2.061 c0,1.268-1.015,2.297-2.267,2.297c-1.205,0-2.188-0.954-2.26-2.156c-0.67,0.937-1.066,2.087-1.066,3.332 c0,3.141,2.513,5.687,5.612,5.687c3.1,0,5.612-2.546,5.612-5.687S15.1,3.717,12.001,3.717z M21.25,9.372 C21.25,16.341,13.853,24,12,24S2.75,16.342,2.75,9.372C2.75,4.196,6.892,0,12,0C17.11,0,21.25,4.196,21.25,9.372z"></path></svg>',
			'pinterest' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path id="pinterest-circle-icon_2_" fill="#EA3145" d="M13.757,17.343c-1.487,0-2.886-0.804-3.365-1.717c0,0-0.8,3.173-0.969,3.785 c-0.596,2.165-2.35,4.331-2.487,4.508c-0.095,0.124-0.305,0.085-0.327-0.078c-0.038-0.276-0.485-3.007,0.041-5.235 c0.264-1.118,1.772-7.505,1.772-7.505s-0.44-0.879-0.44-2.179c0-2.041,1.183-3.565,2.657-3.565c1.252,0,1.857,0.94,1.857,2.068 c0,1.26-0.802,3.142-1.216,4.888c-0.345,1.461,0.734,2.653,2.174,2.653c2.609,0,4.367-3.352,4.367-7.323 c0-3.018-2.032-5.278-5.731-5.278c-4.177,0-6.782,3.116-6.782,6.597c0,1.2,0.355,2.047,0.909,2.701 c0.255,0.301,0.29,0.422,0.198,0.767c-0.067,0.254-0.218,0.864-0.281,1.106c-0.092,0.349-0.375,0.474-0.69,0.345 c-1.923-0.785-2.82-2.893-2.82-5.262c0-3.912,3.3-8.604,9.844-8.604c5.259,0,8.72,3.805,8.72,7.89 C21.188,13.307,18.185,17.343,13.757,17.343z"></path> </g></svg>',
			'print' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path fill="#222222" d="M23.186,10.967c-0.544-0.543-1.195-0.815-1.955-0.815h-0.923V6.459c0-0.384-0.096-0.808-0.289-1.269 c-0.192-0.462-0.423-0.827-0.692-1.096l-2.193-2.192c-0.269-0.269-0.635-0.5-1.096-0.692c-0.462-0.192-0.884-0.288-1.269-0.288 H5.077c-0.385,0-0.712,0.135-0.981,0.404C3.827,1.596,3.692,1.923,3.692,2.308v7.846H2.769c-0.76,0-1.411,0.272-1.954,0.815 S0,12.164,0,12.923v6c0,0.125,0.046,0.233,0.137,0.325c0.091,0.091,0.2,0.137,0.324,0.137h3.231v2.308 c0,0.385,0.135,0.712,0.404,0.981c0.269,0.269,0.596,0.404,0.981,0.404h13.846c0.384,0,0.712-0.135,0.981-0.404 c0.269-0.269,0.404-0.596,0.404-0.981v-2.308h3.231c0.125,0,0.233-0.046,0.324-0.137C23.954,19.156,24,19.048,24,18.923v-6 C24,12.161,23.729,11.51,23.186,10.967z M17.451,20.218H6.549v-2.682h10.902L17.451,20.218L17.451,20.218z M17.451,11.998H6.549 v-8.22h8.221v1.297c0,0.385,0.135,0.711,0.404,0.981c0.269,0.269,0.596,0.404,0.981,0.404h1.297v5.538H17.451z M21.861,13.949 c-0.227,0.227-0.495,0.34-0.805,0.34s-0.579-0.114-0.805-0.34c-0.227-0.226-0.34-0.495-0.34-0.805s0.113-0.579,0.34-0.805 c0.227-0.227,0.495-0.34,0.805-0.34s0.579,0.113,0.805,0.34c0.227,0.227,0.34,0.495,0.34,0.805S22.088,13.723,21.861,13.949z"></path> </g></svg>',
			'reddit' => '<svg viewBox="0 0 24 24" class="svg-icon"><path id="Reddit_1_" fill="#FF5C1F" d="M23.999,11.786c0-1.576-1.294-2.858-2.885-2.858c-0.689,0-1.321,0.241-1.817,0.641 c-1.759-1.095-3.991-1.755-6.383-1.895l1.248-3.91l3.43,0.8c0.09,1.237,1.134,2.217,2.405,2.217c1.33,0,2.412-1.072,2.412-2.391 c0-1.318-1.082-2.39-2.412-2.39c-0.93,0-1.739,0.525-2.141,1.291l-3.985-0.93c-0.334-0.078-0.671,0.112-0.775,0.436L11.547,7.65 C8.969,7.712,6.546,8.375,4.658,9.534c-0.49-0.38-1.105-0.607-1.774-0.607C1.293,8.927,0,10.209,0,11.785 c0,0.974,0.495,1.836,1.249,2.351c-0.031,0.227-0.048,0.455-0.048,0.686c0,1.97,1.156,3.803,3.254,5.16 C6.468,21.283,9.13,22,11.952,22s5.485-0.716,7.496-2.018c2.099-1.357,3.254-3.19,3.254-5.16c0-0.21-0.014-0.419-0.041-0.626 C23.464,13.689,23.999,12.798,23.999,11.786 M19.997,3.299c0.607,0,1.102,0.49,1.102,1.091c0,0.602-0.494,1.092-1.102,1.092 s-1.102-0.49-1.102-1.092C18.896,3.789,19.389,3.299,19.997,3.299 M6.805,13.554c0-0.888,0.752-1.633,1.648-1.633 c0.897,0,1.625,0.745,1.625,1.633c0,0.889-0.728,1.61-1.625,1.61C7.557,15.163,6.805,14.442,6.805,13.554 M15.951,18.288 c-0.836,0.827-2.124,1.229-3.939,1.229c-0.004,0-0.008-0.001-0.013-0.001c-0.004,0-0.008,0.001-0.013,0.001 c-1.815,0-3.103-0.402-3.938-1.229c-0.256-0.254-0.256-0.665,0-0.919c0.256-0.253,0.671-0.253,0.927,0 c0.576,0.571,1.561,0.849,3.01,0.849c0.005,0,0.009,0.001,0.013,0.001c0.005,0,0.009-0.001,0.013-0.001 c1.45,0,2.435-0.278,3.012-0.849c0.256-0.254,0.671-0.253,0.927,0C16.206,17.623,16.206,18.034,15.951,18.288 M15.569,15.163 c-0.897,0-1.651-0.721-1.651-1.61s0.754-1.633,1.651-1.633s1.625,0.745,1.625,1.633C17.193,14.442,16.466,15.163,15.569,15.163"></path></svg>',
			'rss' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path id="rss-circle-icon_2_" fill="#FFAD1D" d="M4.695,22c-1.497,0-2.71-1.212-2.71-2.706c0-1.495,1.213-2.707,2.71-2.707 s2.71,1.212,2.71,2.707C7.406,20.788,6.193,22,4.695,22z M11.171,22c-0.052-5.035-4.144-9.122-9.186-9.173V8.818 C9.252,8.869,15.133,14.743,15.185,22H11.171L11.171,22z M17.971,22c-0.013-4.266-1.681-8.276-4.702-11.293 C10.253,7.694,6.248,6.029,1.985,6.01V2c11.038,0.039,19.975,8.974,20,20H17.971L17.971,22z"></path> </g></svg>',
			'weibo' => '<svg viewBox="0 0 24 24" class="svg-icon"><path fill="#FF3F3F" d="M8.047,12.841c-1.923,0.426-3.146,2.32-2.742,4.248c0.715,1.835,2.774,2.754,4.618,2.06 c1.923-0.426,3.146-2.32,2.742-4.248C11.95,13.066,9.891,12.148,8.047,12.841z M8.131,17.72L8.131,17.72 c-0.624,0.263-1.344-0.018-1.624-0.635c-0.109-0.668,0.334-1.302,0.999-1.429c0.624-0.263,1.344,0.018,1.624,0.635 C9.238,16.959,8.796,17.593,8.131,17.72z M10.134,15.729c-0.059,0.034-0.125,0.054-0.192,0.058c-0.204,0.12-0.467,0.052-0.587-0.152 c-0.12-0.204-0.052-0.467,0.152-0.586c0.059-0.035,0.125-0.055,0.193-0.058c0.204-0.12,0.466-0.052,0.586,0.152 C10.406,15.346,10.338,15.609,10.134,15.729z"></path> <path fill="#FF3F3F" d="M17.468,11.532c0.609-0.913,0.662-2.089,0.138-3.053c-0.877-1.134-3.137-0.928-5.619,0.313 c-0.143,0.068-0.315,0.006-0.382-0.137c-0.034-0.072-0.036-0.155-0.007-0.229c0.478-1.26,0.485-2.327-0.096-2.936 c-1.255-1.316-4.765-0.007-7.839,2.925c-4.073,3.61-3.656,7.337-3.646,7.471c0.258,3.639,5.144,6.258,10.914,5.849 c5.77-0.409,9.98-3.682,9.98-7.33C20.91,13.051,19.557,12.093,17.468,11.532z M9.968,20.273c-3.909,0.277-7.226-1.596-7.409-4.185 c-0.183-2.588,2.836-4.911,6.745-5.188c3.909-0.277,7.226,1.596,7.41,4.185C16.897,17.673,13.877,19.996,9.968,20.273z"></path> <path fill="#FF3F3F" d="M19.905,9.416c0.001,0,0.001,0,0.002,0c0.043,0.007,0.085,0.01,0.128,0.01c0.416,0,0.77-0.305,0.832-0.716 c0.283-1.843-0.982-3.566-2.825-3.848c-0.34-0.052-0.687-0.052-1.027,0c-0.46,0.074-0.773,0.507-0.699,0.967 c0.074,0.458,0.502,0.77,0.96,0.7c0.941-0.124,1.805,0.537,1.929,1.478c0.008,0.063,0.013,0.125,0.014,0.188 c0,0.087-0.007,0.174-0.02,0.26C19.13,8.915,19.445,9.345,19.905,9.416z"></path> <path fill="#FF3F3F" d="M19.112,1.927c-0.516-0.13-1.046-0.196-1.578-0.197c-0.38,0-0.759,0.033-1.134,0.099 c-0.459,0.081-0.765,0.518-0.684,0.977c0.081,0.459,0.518,0.765,0.977,0.684c0.277-0.049,0.559-0.074,0.841-0.074 c2.642,0.003,4.781,2.147,4.778,4.789c0,0.392-0.049,0.783-0.145,1.163c-0.114,0.451,0.16,0.91,0.611,1.024 c0.451,0.114,0.91-0.16,1.024-0.611C24.676,6.318,22.576,2.801,19.112,1.927z"></path></svg>',
			'skype' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path id="skype-icon_2_" fill="#06BCFF" d="M23.016,13.971c0.111-0.638,0.173-1.293,0.173-1.963 c0-6.213-5.014-11.249-11.199-11.249c-0.704,0-1.393,0.068-2.061,0.193C8.939,0.348,7.779,0,6.536,0C2.926,0,0,2.939,0,6.565 c0,1.264,0.357,2.443,0.973,3.445c-0.116,0.649-0.18,1.316-0.18,1.999c0,6.212,5.014,11.25,11.198,11.25 c0.719,0,1.419-0.071,2.099-0.201C15.075,23.656,16.229,24,17.465,24C21.074,24,24,21.061,24,17.435 C24,16.163,23.639,14.976,23.016,13.971z M12.386,19.88c-3.19,0-6.395-1.453-6.378-3.953c0.005-0.754,0.565-1.446,1.312-1.446 c1.877,0,1.86,2.803,4.85,2.803c2.098,0,2.814-1.15,2.814-1.95c0-2.894-9.068-1.12-9.068-6.563c0-2.945,2.409-4.977,6.196-4.753 c3.61,0.213,5.727,1.808,5.932,3.299c0.102,0.973-0.543,1.731-1.662,1.731c-1.633,0-1.8-2.188-4.613-2.188 c-1.269,0-2.341,0.53-2.341,1.679c0,2.402,9.014,1.008,9.014,6.295C18.441,17.882,16.012,19.88,12.386,19.88z"></path> </g></svg>',
			'slack' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path fill="#222222" d="M23.817,12.494c-0.473-1.059-1.717-1.535-2.776-1.062l-1.011,0.453l-2.592-5.794l1.011-0.452 c1.059-0.475,1.534-1.717,1.06-2.776c-0.473-1.06-1.716-1.536-2.776-1.061l-1.011,0.453l-0.453-1.012 c-0.474-1.059-1.717-1.533-2.776-1.059c-1.059,0.473-1.533,1.715-1.06,2.776l0.453,1.011L6.092,6.562L5.64,5.551 C5.166,4.49,3.923,4.017,2.863,4.49C1.804,4.964,1.33,6.207,1.803,7.266l0.452,1.011L1.244,8.73 c-1.059,0.474-1.534,1.715-1.06,2.775c0.473,1.059,1.717,1.534,2.776,1.061l1.011-0.453l2.591,5.795L5.551,18.36 c-1.059,0.474-1.533,1.717-1.06,2.776c0.474,1.06,1.717,1.535,2.776,1.062l1.011-0.453l0.453,1.011 c0.474,1.06,1.717,1.534,2.776,1.06c1.059-0.473,1.533-1.716,1.059-2.775l-0.451-1.012l5.794-2.591l0.452,1.008 c0.474,1.062,1.716,1.537,2.776,1.063c1.059-0.472,1.534-1.716,1.06-2.776l-0.452-1.011l1.01-0.453 C23.816,14.795,24.291,13.553,23.817,12.494z M10.399,16.193l-2.591-5.796l5.794-2.591l2.591,5.794L10.399,16.193z"></path> </g></svg>',
			'snapchat' => '<svg viewBox="0 0 24 24" class="svg-icon"><path id="Snapchat" fill="#FADA06" d="M12.231,0.751L12.231,0.751c-0.022,0-0.041,0-0.06,0c-0.148,0.001-0.391,0.004-0.413,0.004 c-0.533,0-1.599,0.075-2.744,0.579C8.359,1.622,7.77,2.011,7.264,2.491C6.66,3.063,6.168,3.768,5.802,4.587 C5.266,5.786,5.393,7.806,5.495,9.429v0.003c0.011,0.174,0.023,0.355,0.033,0.532C5.449,10,5.322,10.038,5.134,10.038 c-0.302,0-0.662-0.096-1.069-0.286c-0.12-0.056-0.256-0.084-0.407-0.084c-0.242,0-0.497,0.071-0.719,0.201 c-0.279,0.163-0.459,0.394-0.507,0.649C2.4,10.687,2.401,11.021,2.774,11.36c0.205,0.187,0.505,0.359,0.894,0.512 c0.102,0.04,0.223,0.078,0.351,0.119c0.444,0.141,1.117,0.354,1.292,0.765c0.089,0.209,0.051,0.483-0.113,0.815 c-0.004,0.009-0.009,0.018-0.013,0.027c-0.041,0.095-0.423,0.959-1.208,1.87c-0.446,0.518-0.937,0.951-1.458,1.287 c-0.637,0.41-1.326,0.679-2.048,0.797c-0.284,0.046-0.486,0.298-0.47,0.584c0.005,0.082,0.024,0.165,0.058,0.244 c0,0.001,0.001,0.001,0.001,0.001c0.115,0.267,0.38,0.494,0.812,0.695c0.528,0.245,1.318,0.45,2.347,0.611 c0.052,0.099,0.106,0.346,0.143,0.516c0.039,0.18,0.08,0.366,0.138,0.563c0.063,0.213,0.226,0.468,0.644,0.468 c0.158,0,0.341-0.036,0.552-0.076c0.309-0.06,0.732-0.143,1.259-0.143c0.292,0,0.595,0.026,0.901,0.076 c0.588,0.098,1.095,0.455,1.682,0.868c0.859,0.605,1.83,1.29,3.315,1.29c0.04,0,0.081-0.001,0.121-0.004 c0.049,0.002,0.11,0.004,0.174,0.004c1.485,0,2.457-0.685,3.314-1.29l0.001-0.001c0.587-0.413,1.093-0.77,1.681-0.867 c0.305-0.05,0.608-0.076,0.901-0.076c0.504,0,0.903,0.064,1.259,0.133c0.233,0.046,0.413,0.068,0.552,0.068h0.014h0.014 c0.306,0,0.531-0.167,0.616-0.46c0.057-0.193,0.098-0.374,0.138-0.557c0.035-0.159,0.091-0.414,0.143-0.514 c1.03-0.161,1.819-0.367,2.347-0.611c0.431-0.199,0.697-0.426,0.812-0.692c0.034-0.08,0.055-0.163,0.059-0.247 c0.016-0.286-0.187-0.538-0.47-0.584c-3.208-0.527-4.654-3.814-4.714-3.954c-0.004-0.009-0.008-0.018-0.013-0.027 c-0.164-0.332-0.202-0.606-0.113-0.815c0.175-0.411,0.847-0.624,1.292-0.765c0.129-0.04,0.25-0.079,0.351-0.119 c0.438-0.172,0.751-0.359,0.957-0.572c0.247-0.253,0.295-0.496,0.292-0.655c-0.008-0.384-0.302-0.725-0.77-0.893 c-0.158-0.065-0.339-0.1-0.522-0.1c-0.125,0-0.31,0.017-0.486,0.099c-0.375,0.175-0.712,0.271-1,0.285 c-0.154-0.008-0.261-0.041-0.331-0.073c0.009-0.15,0.019-0.304,0.029-0.464l0.004-0.069c0.103-1.624,0.231-3.646-0.306-4.846 c-0.368-0.822-0.862-1.529-1.468-2.102c-0.509-0.48-1.099-0.87-1.757-1.157C13.83,0.826,12.764,0.751,12.231,0.751"></path></svg>',
			'soundcloud' => '<svg viewBox="0 0 24 24" class="svg-icon"><path id="Soundcloud" fill="#FF8800" d="M10.308,18.456V6.134c0-0.393,0.115-0.627,0.346-0.702c0.499-0.121,0.994-0.181,1.486-0.181 c1.139,0,2.2,0.272,3.183,0.815C16.306,6.609,17.1,7.35,17.707,8.29s0.959,1.976,1.055,3.109c0.454-0.196,0.938-0.294,1.452-0.294 c1.042,0,1.934,0.374,2.675,1.121C23.63,12.974,24,13.872,24,14.921c0,1.057-0.37,1.959-1.111,2.707s-1.629,1.121-2.664,1.121 l-9.716-0.011c-0.067-0.023-0.117-0.064-0.151-0.125C10.324,18.554,10.308,18.501,10.308,18.456z M7.694,18.127 c0,0.415,0.275,0.623,0.826,0.623c0.551,0,0.826-0.208,0.826-0.623V6.802c0-0.634-0.204-1.066-0.574-1.114 C8.521,5.656,8.289,5.656,8.051,5.86C7.813,6.064,7.694,6.432,7.694,6.802V18.127L7.694,18.127z M5.126,18.093 c0,0.219,0.078,0.383,0.235,0.493s0.357,0.164,0.603,0.164c0.238,0,0.434-0.055,0.586-0.164c0.153-0.109,0.229-0.274,0.229-0.493 v-6.988c0-0.234-0.08-0.434-0.24-0.6c-0.16-0.166-0.352-0.249-0.575-0.249c-0.231,0-0.428,0.083-0.592,0.249s-0.246,0.366-0.246,0.6 L5.126,18.093L5.126,18.093z M2.568,17.731c0,0.219,0.076,0.383,0.229,0.493c0.153,0.109,0.348,0.164,0.586,0.164 c0.246,0,0.445-0.055,0.598-0.164S4.21,17.95,4.21,17.731v-7.656c0-0.227-0.08-0.421-0.24-0.583S3.614,9.248,3.384,9.248 c-0.223,0-0.415,0.081-0.575,0.244c-0.16,0.162-0.24,0.357-0.24,0.583v7.656H2.568z M0,16.327c0,0.302,0.108,0.53,0.324,0.685 c0.216,0.155,0.447,0.209,0.692,0.164c0.231-0.045,0.393-0.128,0.486-0.249c0.093-0.121,0.14-0.321,0.14-0.6v-3.284 c0-0.234-0.08-0.432-0.24-0.595c-0.16-0.162-0.356-0.244-0.586-0.244c-0.223,0-0.415,0.081-0.575,0.244 c-0.16,0.162-0.24,0.361-0.24,0.595v3.284H0z"></path></svg>',
			'spotify' => '<svg viewBox="0 0 24 24" class="svg-icon"><g id="_x34__stroke"> <g id="Spotify_1_"> <path id="Spotify" fill="#28C858" d="M19.405,19.397c-0.338,0.507-0.929,0.676-1.436,0.338C14,17.286,9.017,16.779,3.106,18.13 c-0.591,0.169-1.098-0.253-1.267-0.76c-0.169-0.591,0.253-1.098,0.76-1.267c6.418-1.436,11.992-0.844,16.383,1.858 C19.574,18.214,19.658,18.89,19.405,19.397 M21.432,14.752c-0.422,0.591-1.182,0.845-1.773,0.422 c-4.56-2.787-11.485-3.631-16.806-1.942c-0.676,0.169-1.436-0.169-1.605-0.845c-0.169-0.676,0.169-1.436,0.844-1.605 c6.165-1.858,13.766-0.929,19.001,2.28C21.601,13.316,21.854,14.161,21.432,14.752 M21.601,10.023 C16.196,6.814,7.16,6.476,2.008,8.081C1.163,8.334,0.319,7.828,0.066,7.068c-0.253-0.845,0.253-1.689,1.013-1.942 c5.996-1.773,15.877-1.436,22.126,2.28c0.76,0.422,1.013,1.436,0.591,2.196C23.374,10.191,22.361,10.445,21.601,10.023"></path> </g> </g></svg>',
			'stackoverflow' => '<svg viewBox="0 0 24 24" class="svg-icon"><g id="_x34__stroke"> <g id="Stack_Overflow"> <g id="Stack_Overflow_1_"> <path fill="#FF780D" d="M19.123,9.804l-5.384-7.828l-1.686,1.14l5.384,7.828L19.123,9.804z M17.105,11.222L8.874,6.408 L7.837,8.151l8.231,4.814L17.105,11.222z M15.901,13.536l-9.228-2.46l-0.53,1.954l9.228,2.46L15.901,13.536z M15.273,16.177 l-9.515-0.869l-0.187,2.015l9.515,0.869L15.273,16.177z M21.5,9.335L19.865,0l-2.011,0.346l1.634,9.335L21.5,9.335z M15.043,20.796L5.487,20.8l-0.001-2.024l9.555-0.005L15.043,20.796z"></path> <polygon fill="#FF780D" points="16.666,14.139 16.666,22.412 4.132,22.412 4.132,14.139 2.5,14.139 2.5,24 18.29,24 18.29,14.139 			"></polygon> </g> </g> </g></svg>',
			'stumbleupon' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path id="stumbleupon-circle-icon_1_" fill="#EB4924" d="M12,6.953c-0.701,0-1.27,0.569-1.27,1.27v7.653 c-0.041,2.927-2.428,5.288-5.365,5.288C2.401,21.164,0,18.763,0,15.799c0-0.039,0-3.327,0-3.327h4.106v3.284 c0,0.701,0.569,1.27,1.27,1.27c0.702,0,1.27-0.569,1.27-1.27c0,0,0-4.708,0-7.749c0-3.041,2.457-5.17,5.354-5.17 c2.908,0,5.354,2.277,5.354,5.202v1.696l-2.504,0.846L13.27,9.7V8.223C13.27,7.521,12.702,6.953,12,6.953z M24,15.799 c0,2.964-2.402,5.365-5.365,5.365c-2.947,0-5.339-2.377-5.366-5.317v-3.344l1.582,0.881l2.503-0.847v3.372 c0,0.701,0.569,1.27,1.27,1.27s1.269-0.569,1.269-1.27v-3.437H24C24,12.472,24,15.76,24,15.799z"></path> </g></svg>',
			'telegram' => '<svg viewBox="0 0 24 24" class="svg-icon"><path fill="#2CA5E0" d="M20.562,2.011c2.346-0.215,1.191,2.728,0.876,3.897c-0.312,1.171-1.826,5.546-5.01,14.397 c-0.412,1.147-0.853,2.533-1.545,3.24c-0.229,0.236-0.641,0.577-1.251,0.41c-0.988-0.27-1.48-1.34-1.92-2.173 c-0.592-1.119-1.199-2.335-1.713-3.487c-0.337-0.759-0.622-1.563-1.084-2.216c-0.563-0.793-1.433-1.217-2.381-1.641 c-1.28-0.572-4.863-2.204-5.259-2.46c-0.852-0.554-1.81-1.587-0.918-2.747C0.725,8.754,1.673,8.432,2.736,8.04 C3.801,7.651,15.13,3.625,19.31,2.257C19.621,2.157,20.256,2.003,20.562,2.011L20.562,2.011z"></path></svg>',
			'tumblr' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path id="tumblr-square-rounded-icon_3_" fill="#35465C" d="M19.44,22.887c-1.034,0.487-1.97,0.828-2.808,1.024 c-0.838,0.195-1.744,0.293-2.718,0.293c-1.106,0-2.083-0.14-2.933-0.418c-0.851-0.279-1.575-0.677-2.175-1.194 c-0.6-0.518-1.017-1.067-1.248-1.649c-0.231-0.581-0.347-1.425-0.347-2.53V9.93H4.56V6.482c0.947-0.309,1.759-0.751,2.434-1.327 C7.67,4.58,8.212,3.889,8.62,3.081C9.029,2.274,9.311,1.247,9.464,0h3.429v6.131h5.747V9.93h-5.747v6.208 c0,1.403,0.074,2.304,0.223,2.702c0.149,0.399,0.426,0.718,0.829,0.954c0.536,0.322,1.148,0.483,1.838,0.483 c1.225,0,2.444-0.399,3.657-1.196V22.887L19.44,22.887z"></path> </g></svg>',
			'viadeo' => '<svg viewBox="0 0 24 24" class="svg-icon"><g id="_x31__stroke"> <g id="Viadeo_1_"> <g id="Viadeo"> <path fill="#FF7452" d="M21.046,0.546c-1.011,2.159-2.882,2.557-2.882,2.557c-1.87,0.476-2.525,1.202-2.525,1.202 c-1.871,1.889-0.396,4.181-0.396,4.181c4.039-0.922,5.514-4.259,5.514-4.259c-0.181,2.242-4.986,4.887-4.986,4.887 c1.592,1.565,3.111,1.374,4.112,0.775c1.328-0.795,1.968-2.537,1.968-2.537C23.142,3.484,21.046,0.546,21.046,0.546z M14.424,7.082c0.044,0.662,0.772,12.464-5.445,14.829c0,0,0.571,0.108,1.216,0.079c0,0,7.912-5.015,4.283-14.745 C14.478,7.244,14.463,7.185,14.424,7.082z M11.113,0c1.988,3.356,3.067,6.364,3.311,7.081V7.052C13.936,1.88,11.113,0,11.113,0z"></path> <path fill="#FF7452" d="M16.465,15.438c0,1.192-0.283,2.301-0.85,3.332c-0.566,1.031-1.328,1.825-2.295,2.385 c-0.962,0.559-2.022,0.839-3.169,0.839c-1.153,0-2.207-0.28-3.169-0.839C6.02,20.595,5.253,19.8,4.687,18.769 c-0.566-1.03-0.85-2.139-0.85-3.332c0-1.845,0.62-3.42,1.861-4.725c1.24-1.3,2.725-1.953,4.454-1.953 c0.82,0,1.587,0.152,2.3,0.447c0.073-0.756,0.337-1.457,0.625-2.032c-0.899-0.329-1.87-0.491-2.92-0.491 c-2.496,0-4.561,0.923-6.197,2.772c-1.485,1.673-2.232,3.656-2.232,5.932c0,2.301,0.786,4.313,2.354,6.031 C5.655,23.141,7.677,24,10.152,24c2.466,0,4.488-0.859,6.056-2.581c1.573-1.722,2.354-3.734,2.354-6.031 c0-1.232-0.215-2.375-0.645-3.425c-0.723,0.447-1.406,0.677-1.973,0.8C16.295,13.578,16.465,14.471,16.465,15.438z"></path> </g> </g> </g></svg>',
			'viber' => '<svg viewBox="0 0 24 24" class="svg-icon"><g id="_x34__stroke_1_"> <g id="Viber_2_"> <path id="Viber_3_" fill="#9D62CC" d="M14.957,5.825c0.764,0.163,1.349,0.453,1.849,0.921c0.643,0.608,0.996,1.343,1.151,2.4 c0.105,0.689,0.062,0.96-0.182,1.184c-0.229,0.209-0.651,0.217-0.907,0.019c-0.186-0.139-0.244-0.286-0.287-0.685 c-0.05-0.53-0.143-0.902-0.302-1.246c-0.341-0.731-0.942-1.111-1.957-1.235c-0.477-0.058-0.62-0.112-0.775-0.294 c-0.283-0.337-0.174-0.883,0.217-1.084c0.147-0.074,0.209-0.081,0.535-0.062C14.5,5.755,14.798,5.79,14.957,5.825z M14.131,2.902 c2.353,0.344,4.175,1.436,5.369,3.209c0.671,0.999,1.089,2.171,1.233,3.429c0.05,0.461,0.05,1.3-0.004,1.44 c-0.051,0.131-0.213,0.309-0.353,0.383c-0.151,0.078-0.473,0.07-0.651-0.023c-0.298-0.151-0.388-0.391-0.388-1.041 c0-1.002-0.26-2.059-0.709-2.88c-0.512-0.937-1.256-1.711-2.163-2.249c-0.779-0.465-1.93-0.809-2.981-0.894 c-0.38-0.031-0.589-0.108-0.733-0.275c-0.221-0.252-0.244-0.592-0.058-0.875C12.895,2.813,13.205,2.763,14.131,2.902z M5.002,0.514c0.136,0.047,0.345,0.155,0.465,0.232c0.736,0.488,2.787,3.108,3.458,4.416c0.384,0.747,0.512,1.3,0.392,1.711 C9.193,7.314,8.988,7.547,8.069,8.286C7.701,8.584,7.356,8.89,7.301,8.971C7.162,9.172,7.049,9.567,7.049,9.846 c0.004,0.646,0.423,1.819,0.973,2.721c0.426,0.7,1.19,1.598,1.946,2.287c0.888,0.813,1.671,1.366,2.555,1.804 c1.136,0.565,1.83,0.708,2.337,0.472c0.128-0.058,0.264-0.135,0.306-0.17c0.039-0.035,0.337-0.399,0.663-0.801 c0.628-0.79,0.771-0.917,1.202-1.065c0.547-0.186,1.105-0.135,1.667,0.151c0.427,0.221,1.357,0.797,1.957,1.215 c0.791,0.553,2.481,1.931,2.71,2.206c0.403,0.495,0.473,1.13,0.202,1.831c-0.287,0.739-1.403,2.125-2.182,2.717 c-0.705,0.534-1.206,0.739-1.865,0.77c-0.543,0.027-0.768-0.019-1.461-0.306c-5.442-2.241-9.788-5.585-13.238-10.179 c-1.802-2.4-3.175-4.888-4.113-7.47c-0.547-1.505-0.574-2.16-0.124-2.93c0.194-0.325,1.019-1.13,1.62-1.579 c1-0.743,1.461-1.018,1.83-1.095C4.285,0.371,4.723,0.414,5.002,0.514z M13.864,0.096c1.334,0.166,2.411,0.487,3.593,1.065 c1.163,0.569,1.907,1.107,2.892,2.086c0.923,0.925,1.434,1.626,1.977,2.713c0.756,1.517,1.186,3.321,1.26,5.306 c0.027,0.677,0.008,0.828-0.147,1.022c-0.294,0.375-0.942,0.313-1.163-0.108c-0.07-0.139-0.089-0.259-0.112-0.801 c-0.039-0.832-0.097-1.37-0.213-2.013c-0.458-2.52-1.667-4.532-3.597-5.976c-1.609-1.208-3.272-1.796-5.45-1.924 c-0.737-0.043-0.864-0.07-1.031-0.197c-0.31-0.244-0.326-0.817-0.027-1.084c0.182-0.166,0.31-0.19,0.942-0.17 C13.116,0.027,13.6,0.065,13.864,0.096z"></path> </g> </g></svg>',
			'vimeo' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path id="vimeo-icon_2_" fill="#1AB7EA" d="M24.014,6.284c-0.108,2.339-1.741,5.542-4.9,9.608c-3.267,4.247-6.03,6.371-8.291,6.371 c-1.4,0-2.585-1.293-3.553-3.88c-0.647-2.371-1.293-4.742-1.939-7.113c-0.719-2.585-1.49-3.88-2.315-3.88 c-0.18,0-0.809,0.378-1.886,1.132L0,7.066c1.185-1.042,2.355-2.084,3.506-3.128c1.581-1.367,2.768-2.086,3.56-2.159 c1.87-0.18,3.021,1.099,3.453,3.836c0.466,2.952,0.789,4.789,0.971,5.508c0.539,2.45,1.131,3.673,1.78,3.673 c0.503,0,1.258-0.795,2.266-2.384c1.006-1.589,1.545-2.799,1.617-3.629c0.144-1.371-0.395-2.059-1.617-2.059 c-0.576,0-1.168,0.132-1.779,0.394c1.181-3.869,3.437-5.748,6.767-5.641C22.992,1.551,24.155,3.153,24.014,6.284z"></path> </g></svg>',
			'vine' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path fill="#24C5F9" d="M19.281,12.234c-4.605-0.605-6.736-8.809-3.338-8.809c3.396,0,1.199,6.486,1.199,6.486l3.608,0.077 c0,0,2.85-9.989-4.75-9.989c-7.6,0-5.901,10.622-0.576,13.904c0.05,0.031,0.098,0.059,0.149,0.089 c-2.189,4.545-4.697,6.158-4.697,6.158c-7.053-5.297-6.88-16.725-6.88-16.725H0.511c0,14.076,8.364,19.604,8.767,19.935 C9.68,23.692,10.098,24,10.861,24c0.763,0,1.099-0.307,1.597-0.695c3.012-2.338,5.127-5.622,6.357-8.034 c1.774,0.378,3.408,0.252,4.674-0.006v-3.173C22.592,12.423,21.343,12.505,19.281,12.234z"></path> </g></svg>',
			'vk' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path fill="#3673BE" d="M23.876,17.52c-0.029-0.063-0.056-0.115-0.081-0.156c-0.416-0.75-1.212-1.67-2.387-2.762l-0.025-0.025 l-0.012-0.012l-0.013-0.013h-0.013c-0.533-0.508-0.871-0.85-1.012-1.025c-0.259-0.333-0.317-0.671-0.175-1.012 c0.1-0.258,0.475-0.804,1.125-1.637c0.342-0.442,0.612-0.795,0.812-1.062c1.441-1.916,2.066-3.141,1.874-3.674l-0.074-0.125 c-0.05-0.075-0.096-0.116-0.304-0.178c-0.208-0.062-0.466-0.057-1.107-0.057l-3.03,0.021c-0.155,0-0.486-0.017-0.594,0.008 s-0.163,0.038-0.163,0.038L18.633,5.88l-0.05,0.038c-0.042,0.025-0.087,0.069-0.138,0.131c-0.05,0.062-0.091,0.135-0.125,0.219 c-0.392,1.008-0.837,1.945-1.337,2.811c-0.308,0.517-0.591,0.964-0.85,1.343c-0.258,0.379-0.475,0.658-0.65,0.837 c-0.175,0.179-0.333,0.323-0.475,0.431s-0.25,0.154-0.325,0.138c-0.075-0.017-0.146-0.033-0.213-0.05 c-0.117-0.075-0.21-0.177-0.281-0.306s-0.119-0.292-0.144-0.487c-0.025-0.196-0.04-0.364-0.044-0.506 c-0.004-0.141-0.002-0.342,0.006-0.6c0.009-0.258,0.013-0.433,0.013-0.525c0-0.317,0.006-0.66,0.019-1.031s0.023-0.664,0.031-0.881 s0.012-0.446,0.012-0.687c0-0.242-0.015-0.431-0.044-0.569c-0.029-0.137-0.073-0.271-0.131-0.4s-0.144-0.229-0.256-0.3 c-0.112-0.071-0.252-0.127-0.419-0.169c-0.442-0.1-1.004-0.154-1.687-0.162C9.996,5.138,9,5.238,8.559,5.455 C8.384,5.547,8.226,5.672,8.084,5.83c-0.15,0.183-0.171,0.283-0.063,0.3c0.5,0.075,0.854,0.254,1.062,0.537l0.075,0.15 c0.058,0.108,0.117,0.3,0.175,0.575c0.058,0.275,0.096,0.579,0.112,0.912c0.042,0.608,0.042,1.129,0,1.562 s-0.081,0.771-0.119,1.012c-0.038,0.242-0.094,0.437-0.169,0.587s-0.125,0.242-0.15,0.275s-0.046,0.054-0.062,0.062 c-0.108,0.042-0.221,0.063-0.337,0.063c-0.117,0-0.258-0.058-0.425-0.175c-0.167-0.117-0.339-0.277-0.519-0.481 c-0.179-0.204-0.381-0.489-0.606-0.856c-0.225-0.366-0.458-0.8-0.7-1.299l-0.2-0.362C6.033,8.459,5.862,8.119,5.646,7.674 C5.429,7.228,5.238,6.797,5.071,6.381c-0.067-0.175-0.167-0.308-0.3-0.4L4.708,5.943C4.666,5.91,4.6,5.874,4.508,5.837 C4.416,5.799,3.576,5.766,3.219,5.766L0.831,5.78c-0.35,0-0.621,0.08-0.746,0.239l-0.05,0.075c-0.025,0.042-0.038,0.108-0.038,0.2 s0.025,0.204,0.075,0.337c0.5,1.175,1.043,2.308,1.631,3.399C2.29,11.121,2.801,12,3.234,12.666 c0.433,0.667,0.875,1.296,1.325,1.887c0.45,0.592,0.748,0.971,0.893,1.137c0.146,0.167,0.26,0.292,0.344,0.375l0.312,0.3 c0.2,0.2,0.494,0.439,0.881,0.718c0.387,0.279,0.816,0.554,1.287,0.825c0.471,0.271,1.018,0.491,1.643,0.662 s1.218,0.206,1.824,0.206h1.437c0.291-0.025,0.512-0.117,0.662-0.275l0.05-0.063c0.033-0.05,0.065-0.127,0.094-0.231 s0.044-0.219,0.044-0.344c-0.009-0.358,0.019-0.681,0.081-0.968s0.133-0.504,0.213-0.65c0.079-0.146,0.169-0.269,0.269-0.368 c0.1-0.1,0.171-0.16,0.213-0.181c0.041-0.021,0.075-0.035,0.1-0.044c0.2-0.067,0.435-0.002,0.706,0.194s0.525,0.437,0.762,0.725 s0.523,0.61,0.856,0.968s0.625,0.625,0.875,0.8l0.25,0.15c0.167,0.1,0.383,0.192,0.65,0.275c0.266,0.083,0.401,0.062,0.7,0.062 l3.262-0.003c0.316,0,0.5-0.099,0.674-0.203c0.175-0.104,0.279-0.219,0.312-0.344s0.035-0.267,0.006-0.425 C23.935,17.693,23.905,17.582,23.876,17.52z"></path> </g></svg>',
			'whatsapp' => '<svg viewBox="0 0 24 24" class="svg-icon"><path fill="#13D25A" d="M12.003,0h-0.007l0,0l0,0C5.381,0,0,5.383,0,12c0,2.624,0.846,5.058,2.285,7.034L0.79,23.492l4.612-1.474 C7.299,23.274,9.563,24,12.003,24c6.615,0,11.996-5.383,11.996-12C23.999,5.383,18.618,0,12.003,0z M18.852,16.842 c-0.289,0.818-1.439,1.496-2.356,1.693c-0.628,0.134-1.446,0.24-4.203-0.903c-3.526-1.461-5.797-5.045-5.974-5.277 c-0.169-0.233-1.425-1.898-1.425-3.619s0.875-2.561,1.227-2.92c0.289-0.296,0.769-0.43,1.227-0.43c0.148,0,0.282,0.007,0.402,0.014 c0.352,0.014,0.529,0.035,0.762,0.593C8.8,6.691,9.506,8.413,9.59,8.589c0.085,0.176,0.169,0.416,0.049,0.649 c-0.113,0.24-0.212,0.346-0.388,0.55c-0.176,0.205-0.345,0.36-0.522,0.579c-0.162,0.19-0.346,0.395-0.141,0.748 c0.204,0.346,0.91,1.495,1.946,2.419c1.34,1.192,2.426,1.573,2.814,1.735c0.289,0.12,0.635,0.092,0.846-0.134 c0.268-0.289,0.599-0.769,0.938-1.242c0.24-0.339,0.543-0.381,0.86-0.261c0.324,0.113,2.038,0.959,2.391,1.136 c0.352,0.177,0.585,0.261,0.67,0.409C19.141,15.325,19.141,16.023,18.852,16.842z"></path></svg>',
			'xing' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path id="Xing_2_" fill="#20A5A5" d="M14.766,24l-5.367-9.411L17.729,0h5.605l-8.328,14.589L20.37,24H14.766L14.766,24z M5.954,16.74l4.164-6.853L6.989,4.383H1.706l3.123,5.503L0.667,16.74L5.954,16.74L5.954,16.74z"></path> </g></svg>',
			'youtube' => '<svg viewBox="0 0 24 24" class="svg-icon"><g> <path fill="#EE3130" d="M23.777,6.602c-0.205-1.75-0.625-2.261-0.921-2.494c-0.475-0.371-1.337-0.499-2.487-0.578 c-1.85-0.126-4.979-0.2-8.37-0.2c-3.391,0-6.519,0.074-8.368,0.2C2.482,3.609,1.619,3.738,1.144,4.108 C0.847,4.341,0.429,4.852,0.222,6.602c-0.296,2.522-0.296,8.273,0,10.796c0.207,1.749,0.625,2.26,0.922,2.492 c0.475,0.373,1.338,0.501,2.487,0.58c1.849,0.125,4.978,0.199,8.368,0.199c3.392,0,6.52-0.075,8.37-0.199 c1.15-0.079,2.011-0.207,2.487-0.58c0.296-0.232,0.716-0.743,0.921-2.492C24.074,14.875,24.074,9.125,23.777,6.602z M9.104,15.774 V8.225L16.344,12L9.104,15.774z"></path> </g></svg>',
			'codepen' => '<svg class="svg-icon" enable-background="new 0 0 24 24" id="codepen" version="1.1" viewBox="0 0 30 30" xml:space="preserve" xmlns="http://www.w3.org/2000/svg"><path fill="#222" d="M29.979,10.205c-0.007-0.036-0.014-0.072-0.022-0.107c-0.006-0.021-0.014-0.042-0.021-0.063  c-0.01-0.031-0.021-0.063-0.033-0.094c-0.009-0.021-0.019-0.042-0.028-0.063c-0.014-0.029-0.028-0.058-0.045-0.086  c-0.011-0.021-0.023-0.04-0.036-0.06c-0.018-0.026-0.035-0.053-0.055-0.078c-0.014-0.02-0.028-0.037-0.044-0.056  c-0.021-0.024-0.042-0.047-0.064-0.07c-0.017-0.017-0.033-0.034-0.051-0.05c-0.023-0.021-0.048-0.042-0.073-0.062  c-0.02-0.015-0.038-0.03-0.059-0.044c-0.007-0.005-0.014-0.011-0.021-0.017L15.715,0.216c-0.433-0.288-0.997-0.288-1.43,0  L0.574,9.356C0.566,9.362,0.56,9.368,0.553,9.373c-0.02,0.014-0.039,0.029-0.059,0.044c-0.024,0.02-0.049,0.04-0.073,0.062  C0.404,9.494,0.387,9.512,0.37,9.528c-0.022,0.023-0.044,0.046-0.064,0.07c-0.015,0.019-0.03,0.036-0.044,0.056  C0.242,9.68,0.225,9.706,0.207,9.732c-0.013,0.02-0.025,0.039-0.037,0.06C0.154,9.82,0.14,9.849,0.126,9.878  c-0.01,0.021-0.02,0.041-0.029,0.063c-0.012,0.031-0.023,0.063-0.033,0.094c-0.007,0.021-0.014,0.042-0.02,0.063  c-0.009,0.035-0.016,0.071-0.022,0.107c-0.003,0.019-0.008,0.037-0.011,0.056C0.004,10.316,0,10.373,0,10.43v9.141  c0,0.057,0.004,0.112,0.011,0.168c0.003,0.02,0.007,0.037,0.011,0.056c0.006,0.036,0.013,0.072,0.022,0.108  c0.006,0.021,0.013,0.042,0.02,0.063c0.01,0.031,0.021,0.063,0.033,0.095c0.009,0.021,0.019,0.041,0.029,0.062  c0.014,0.029,0.028,0.058,0.044,0.087c0.011,0.02,0.024,0.039,0.037,0.059c0.018,0.027,0.035,0.053,0.055,0.079  c0.014,0.019,0.029,0.037,0.044,0.055c0.021,0.024,0.042,0.048,0.064,0.07c0.017,0.017,0.034,0.034,0.051,0.05  c0.023,0.021,0.048,0.042,0.073,0.062c0.02,0.016,0.039,0.03,0.059,0.045c0.007,0.005,0.014,0.011,0.021,0.016l13.711,9.141  C14.502,29.928,14.751,30,15,30s0.499-0.072,0.715-0.217l13.711-9.141c0.008-0.005,0.015-0.011,0.021-0.016  c0.021-0.015,0.039-0.029,0.059-0.045c0.025-0.02,0.05-0.04,0.073-0.062c0.018-0.016,0.034-0.033,0.051-0.05  c0.022-0.022,0.044-0.046,0.064-0.07c0.016-0.018,0.03-0.036,0.044-0.055c0.02-0.026,0.037-0.052,0.055-0.079  c0.013-0.02,0.025-0.039,0.036-0.059c0.017-0.029,0.031-0.058,0.045-0.087c0.01-0.021,0.02-0.041,0.028-0.062  c0.013-0.031,0.023-0.063,0.033-0.095c0.007-0.021,0.015-0.041,0.021-0.063c0.009-0.036,0.016-0.072,0.022-0.108  c0.003-0.019,0.008-0.036,0.01-0.056C29.996,19.683,30,19.627,30,19.57V10.43c0-0.057-0.004-0.113-0.012-0.169  C29.986,10.242,29.981,10.224,29.979,10.205z M15,18.05L10.441,15L15,11.95L19.56,15L15,18.05z M13.711,9.711l-5.589,3.738  L3.61,10.432l10.101-6.734V9.711z M5.803,15l-3.225,2.157v-4.314L5.803,15z M8.122,16.551l5.589,3.738v6.013L3.61,19.568  L8.122,16.551z M16.289,20.289l5.589-3.738l4.512,3.018l-10.101,6.733V20.289z M24.196,15l3.226-2.157v4.314L24.196,15z   M21.878,13.449l-5.589-3.738V3.697l10.101,6.734L21.878,13.449z" id="wtf"/></svg>',
			'yelp' => '<svg class="svg-icon" enable-background="new 0 0 24 24" id="Social_Icons" version="1.1" viewBox="0 0 128 128" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g id="_x36__stroke"><g id="Yelp"><path clip-rule="evenodd" d="M64.69,52.375    c-0.366-8.644-2.924-47.155-3.226-48.943c-0.443-1.612-1.679-2.768-3.471-3.228c-5.477-1.384-26.43,4.588-30.317,8.66    c-1.244,1.32-1.712,2.952-1.337,4.388c0.608,1.28,26.579,42.784,26.579,42.784c3.842,6.324,6.971,5.344,7.994,5.02    C61.931,60.731,65.044,59.751,64.69,52.375z M86.26,70.394c21.477-5.284,22.307-5.568,23.156-6.132    c1.297-0.884,1.949-2.376,1.84-4.192c0-0.06,0.008-0.116,0-0.184c-0.552-5.352-9.798-19.296-14.349-21.556    c-1.611-0.788-3.23-0.732-4.559,0.176c-0.83,0.552-1.446,1.38-12.943,17.356c0,0-5.199,7.196-5.259,7.264    c-1.373,1.688-1.385,4.12-0.052,6.2c1.385,2.152,3.729,3.2,5.876,2.596c0,0-0.089,0.152-0.113,0.184    C80.916,71.694,82.813,71.226,86.26,70.394z M96.018,118.052c4.772-1.932,15.191-15.392,15.923-20.572    c0.25-1.8-0.302-3.356-1.526-4.344c-0.797-0.612-1.418-0.852-20.313-7.152c0,0-8.288-2.784-8.397-2.836    c-2.001-0.788-4.297-0.064-5.835,1.876c-1.595,1.98-1.844,4.584-0.568,6.564l3.339,5.516    c11.224,18.516,12.078,19.824,12.887,20.464C92.776,118.568,94.362,118.732,96.018,118.052z M63.907,125.077    c0.33-0.964,0.366-1.632,0.423-21.82c0,0,0.048-8.916,0.052-9.012c0.133-2.18-1.252-4.168-3.54-5.068    c-2.348-0.916-4.873-0.348-6.29,1.452c0,0-4.144,5-4.16,5c-14.244,16.988-14.828,17.772-15.178,18.78    c-0.209,0.6-0.298,1.224-0.221,1.852c0.085,0.896,0.479,1.792,1.148,2.616c3.298,3.992,19.133,9.912,24.187,9.036    C62.087,127.585,63.36,126.581,63.907,125.077z M18.445,61.623c-2.046,3.332-2.908,13.824-2.203,20.788    c0.25,2.3,0.66,4.216,1.252,5.36c0.818,1.58,2.195,2.524,3.765,2.576c1.007,0.056,1.631-0.12,20.543-6.3    c0,0,8.405-2.72,8.441-2.74c2.094-0.536,3.504-2.496,3.645-5c0.133-2.56-1.172-4.828-3.318-5.644c0,0-5.92-2.456-5.936-2.456    c-20.321-8.516-21.231-8.852-22.258-8.864C20.809,59.283,19.408,60.083,18.445,61.623z" fill="#D32200" fill-rule="evenodd" id="Yelp_1_"/></g></g></svg>',
			'wordpress' => '<svg class="svg-icon" enable-background="new 0 0 24 24" height="64px" id="Layer_1" version="1.1" viewBox="0 0 64 64" width="64px" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><path d="M4.55,32c0,10.864,6.312,20.255,15.471,24.704L6.926,20.828C5.402,24.242,4.55,28.019,4.55,32z M50.532,30.615  c0-3.395-1.22-5.743-2.263-7.571c-1.394-2.261-2.697-4.174-2.697-6.438c0-2.521,1.912-4.871,4.611-4.871  c0.119,0,0.233,0.015,0.354,0.021c-4.885-4.474-11.389-7.204-18.538-7.204c-9.591,0-18.025,4.918-22.937,12.371  c0.646,0.02,1.252,0.033,1.77,0.033c2.869,0,7.314-0.351,7.314-0.351c1.479-0.086,1.656,2.089,0.176,2.265  c0,0-1.487,0.173-3.143,0.261l9.998,29.733l6.007-18.017L26.909,19.13c-1.479-0.088-2.879-0.261-2.879-0.261  c-1.481-0.089-1.308-2.351,0.174-2.265c0,0,4.532,0.351,7.229,0.351c2.872,0,7.316-0.351,7.316-0.351  c1.479-0.086,1.655,2.089,0.176,2.265c0,0-1.489,0.173-3.141,0.261l9.92,29.508l2.739-9.147  C49.832,35.921,50.532,32.966,50.532,30.615z M32.482,34.398l-8.237,23.935c2.46,0.726,5.061,1.118,7.754,1.118  c3.196,0,6.263-0.553,9.116-1.555c-0.073-0.117-0.141-0.241-0.195-0.381L32.482,34.398z M56.089,18.83  c0.116,0.875,0.185,1.812,0.185,2.823c0,2.786-0.521,5.917-2.088,9.832l-8.385,24.242c8.163-4.759,13.65-13.601,13.65-23.728  C59.451,27.226,58.23,22.741,56.089,18.83z M0,32c0,17.646,14.356,32,31.999,32C49.643,64,64,49.646,64,32  C64,14.355,49.643,0,31.999,0C14.356,0,0,14.355,0,32z M1.468,32c0-16.834,13.697-30.529,30.531-30.529  c16.837,0,30.534,13.695,30.534,30.529c0,16.835-13.697,30.533-30.534,30.533C15.165,62.533,1.468,48.835,1.468,32z"/></svg>',
			'wechat' => '<svg class="svg-icon" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><g id="Wechat"><path d="M16.5,8V8l.15,0h0a.55.55,0,0,0,.51-.5.5.5,0,0,0-.09-.29C15.92,4.09,12.59,2,8.75,2,3.93,2,0,5.36,0,9.5a7.06,7.06,0,0,0,3.09,5.71l-1,2.07a.5.5,0,0,0,.7.66l2.65-1.51a10,10,0,0,0,2.22.51.5.5,0,0,0,.54-.61A5.8,5.8,0,0,1,8,15C8,11.14,11.81,8,16.5,8ZM11,6a1,1,0,1,1-1,1A1,1,0,0,1,11,6ZM6,8A1,1,0,1,1,7,7,1,1,0,0,1,6,8Z" fill="#38BE2F"/><path d="M24,15c0-3.31-3.36-6-7.5-6S9,11.69,9,15s3.36,6,7.5,6a9.23,9.23,0,0,0,2.3-.29l2.48,1.24a.5.5,0,0,0,.22.05.5.5,0,0,0,.46-.69l-.68-1.7A5.64,5.64,0,0,0,24,15ZM14,14a1,1,0,1,1,1-1A1,1,0,0,1,14,14Zm5,0a1,1,0,1,1,1-1A1,1,0,0,1,19,14Z" fill="#38BE2F"/></g></svg>',
			'twitch' => '<svg class="svg-icon" enable-background="new 0 0 24 24" id="Twitch" version="1.1" viewBox="0 0 30 30" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g id="_x7C___x7C_"><path fill="#63469F" clip-rule="evenodd" d="M21,26h-6l-3,4H8v-4H1V5.132L3,0h26v18L21,26z M26,17V3H5v19h6v4l4-4   h6L26,17z" fill-rule="evenodd" id="Dialog"/><rect fill="#63469F" clip-rule="evenodd" fill-rule="evenodd" height="8" id="_x7C_" width="3" x="18" y="8"/><rect fill="#63469F" clip-rule="evenodd" fill-rule="evenodd" height="8" id="_x7C__1_" width="3" x="12" y="8"/></g></svg>',
			'tripadvisor' => '<svg class="svg-icon" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><g id="Tripadvisor"><circle cx="6" cy="12.98" r="1" fill="#5A9349"/><path d="M6,10a3,3,0,1,0,3,3A3,3,0,0,0,6,10Zm0,5a2,2,0,1,1,2-2A2,2,0,0,1,6,15Z" fill="#5A9349"/><circle cx="18" cy="12.98" r="1" fill="#5A9349"/><path d="M18,10a3,3,0,1,0,3,3A3,3,0,0,0,18,10Zm0,5a2,2,0,1,1,2-2A2,2,0,0,1,18,15Z" fill="#5A9349"/><path d="M23,9.59a5.07,5.07,0,0,1,.93-1.77A.5.5,0,0,0,23.5,7H19.74A16,16,0,0,0,4.26,7H.5a.5.5,0,0,0-.38.82A5,5,0,0,1,1,9.59,6,6,0,0,0,10.48,17l1.09,1.79a.5.5,0,0,0,.85,0L13.52,17A6,6,0,0,0,23,9.59ZM6,18A5,5,0,0,1,4.84,8.12l.31-.06A5,5,0,0,1,6,8,5,5,0,0,1,6,18Zm12,0a5,5,0,0,1-4.14-2.21l0,0c-.09-.13-.15-.27-.22-.41A7.32,7.32,0,0,1,13,12.84,5,5,0,0,1,18,8a5,5,0,0,1,.86.09l.3.06A5,5,0,0,1,18,18Z" fill="#5A9349"/></g></svg>',
			'steam' => '<svg class="svg-icon" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><g id="Steam"><circle cx="15.5" cy="9.5" r="2.5" fill="#303c42"/><path d="M8.67,18.34A1.49,1.49,0,0,1,7,18.13a.5.5,0,0,0-.66.75,2.5,2.5,0,1,0,2-4.35.49.49,0,0,0-.56.43.5.5,0,0,0,.43.56,1.5,1.5,0,0,1,.47,2.83Z" fill="#303c42"/><path d="M12,0A12,12,0,0,0,0,11.5a.5.5,0,0,0,.14.37A.5.5,0,0,0,.4,12c.34.11,3,1.26,4.55,2a.51.51,0,0,0,.52-.07A3.84,3.84,0,0,1,8.33,13a.5.5,0,0,0,.45-.19l2.11-2.76a.5.5,0,0,0,.1-.35c0-.08,0-.15,0-.22A4.5,4.5,0,1,1,15.8,14a.5.5,0,0,0-.28.11l-3.35,2.75a.5.5,0,0,0-.18.36A4,4,0,0,1,8,21a3.94,3.94,0,0,1-3.84-2.93.5.5,0,0,0-.26-.32L2,16.82a.5.5,0,0,0-.67.68A12,12,0,1,0,12,0Z" fill="#303c42"/></g></svg>',
			'producthunt' => '<svg class="svg-icon" enable-background="new 0 0 128 128" id="Social_Icons" version="1.1" viewBox="0 0 128 128" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g id="_x35__stroke"><g id="Product_Hunt"><path clip-rule="evenodd" d="M72.532,44.8L72.532,44.8H54.4V64h18.132 c5.304,0,9.6-4.3,9.6-9.6C82.132,49.1,77.836,44.8,72.532,44.8 M64,0C28.652,0,0,28.652,0,64s28.652,64,64,64    c35.344,0,64-28.652,64-64S99.344,0,64,0 M72.532,76.8L72.532,76.8H54.4V96H41.6V32h30.932c12.372,0,22.4,10.028,22.4,22.4    S84.904,76.8,72.532,76.8" fill="#DE5425" fill-rule="evenodd" id="Product_Hunt_1_"/></g></g></svg>',
			'meetup' => '<svg class="svg-icon" version="1.1" viewBox="10 10 80 80" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g id="color_x5F_fill"><path d="M80.952,74.251c-0.74,0.802-1.917,1.41-3.104,1.721c-3.226,0.844-7.038-0.031-10.038-1.351   c-9.568-4.21-7.455-14.872-3.259-22.225c1.26-2.208,2.503-4.431,3.754-6.666c0.984-1.76,3.114-4.724,2.28-6.875   c-0.875-2.256-3.216-2.27-4.753-0.369c-1.479,1.829-2.726,4.454-3.746,6.584c-1.111,2.319-6.656,14.507-6.656,14.507   c-1.024,1.985-2.751,4.839-4.624,6.416c-1.397,1.177-3.95,1.522-5.629,0.303c-1.275-0.927-1.527-2.159-1.277-3.594   c1.156-6.625,11.204-22.04,4.274-23.125c-2.656-0.416-3.377,2.539-4.196,4.426c-1.354,3.116-2.386,6.361-3.834,9.441   c-1.664,3.536-2.939,7.219-3.813,11.02c-0.698,3.037-1.602,6.907-5.06,7.832c-9.465,2.531-12.341-3.718-12.341-3.719   c-1.545-4.916-0.08-9.338,1.408-14.066c1.15-3.652,1.837-7.419,3.293-10.973c2.598-6.336,5.187-19.556,14.549-18.711   c2.39,0.216,5.063,1.424,7.128,2.628c1.877,1.095,3.305,1.679,5.49,0.499c2.126-1.146,3.099-3.277,5.632-4.008   c2.715-0.783,4.5,0.376,6.53,2.009c2.846,2.288,3.156,1.254,5.504,0.653c1.947-0.499,4.208-0.73,6.342-0.365   c10.982,1.882,3.988,15.901,1.368,21.535c-1.705,3.665-9.844,18.404-2.633,20.385c2.175,0.597,4.979,0.325,6.79,1.885   C82.172,71.633,81.989,73.13,80.952,74.251z" fill="#ED1C40"/></g><g id="offset_x5F_print_x5F_outline"/></svg>',
			'medium' => '<svg class="svg-icon" viewBox="0 0 1792 1792" xmlns="http://www.w3.org/2000/svg"><path d="M597 421v1173q0 25-12.5 42.5t-36.5 17.5q-17 0-33-8l-465-233q-21-10-35.5-33.5t-14.5-46.5v-1140q0-20 10-34t29-14q14 0 44 15l511 256q3 3 3 5zm64 101l534 866-534-266v-600zm1131 18v1054q0 25-14 40.5t-38 15.5-47-13l-441-220zm-3-120q0 3-256.5 419.5t-300.5 487.5l-390-634 324-527q17-28 52-28 14 0 26 6l541 270q4 2 4 6z"/></svg>'
		];

		return empty($icon) ? $icons : $icons[$icon];

	}

}

$widgets_manager->register_widget_type(new Massive_SocialIcons_Widget());